@@ -124,6 +124,9 @@ class ignition::rendering::OgreGpuRaysPrivate
 
   /// \brief Number of cameras needed to generate the rays.
   public: unsigned int cameraCount = 1;
+
+  /// \brief Min allowed angle in radians;
+  public: const math::Angle kMinAllowedAngle = 1e-4;
 };
 
 using namespace ignition;
@@ -245,7 +248,9 @@ void OgreGpuRays::CreateCamera()
 void OgreGpuRays::ConfigureCameras()
 {
   // horizontal gpu rays setup
-  this->SetHFOV(this->AngleMax() - this->AngleMin());
+  auto hfovAngle = this->AngleMax() - this->AngleMin();
+  hfovAngle = std::max(this->dataPtr->kMinAllowedAngle, hfovAngle);
+  this->SetHFOV(hfovAngle);
 
   if (this->HFOV().Radian() > 2.0 * IGN_PI)
   {
@@ -288,7 +293,8 @@ void OgreGpuRays::ConfigureCameras()
 
   if (this->VerticalRangeCount() > 1)
   {
-    vfovAngle = (this->VerticalAngleMax() - this->VerticalAngleMin()).Radian();
+    vfovAngle = std::max(this->dataPtr->kMinAllowedAngle.Radian(),
+        (this->VerticalAngleMax() - this->VerticalAngleMin()).Radian());
   }
   else
   {
@@ -428,7 +434,7 @@ void OgreGpuRays::CreateGpuRaysTextures()
     vp->setSkiesEnabled(false);
     vp->setBackgroundColour(
         Ogre::ColourValue(this->dataMaxVal, 0.0, 1.0));
-    vp->setVisibilityMask(IGN_VISIBILITY_ALL &
+    vp->setVisibilityMask(this->VisibilityMask() &
         ~(IGN_VISIBILITY_GUI | IGN_VISIBILITY_SELECTABLE));
   }
 
