@@ -24,18 +24,18 @@
 #include <set>
 #include <vector>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/common/Util.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/common/Util.hh>
 
-#include "gz/rendering/config.hh"
-#include "gz/rendering/ogre/OgreRenderEngine.hh"
-#include "gz/rendering/ogre/OgreScene.hh"
-#include "gz/rendering/ogre/OgreMaterial.hh"
-#include "gz/rendering/ogre/OgreMesh.hh"
-#include "gz/rendering/ogre/OgreRTShaderSystem.hh"
+#include "ignition/rendering/config.hh"
+#include "ignition/rendering/ogre/OgreRenderEngine.hh"
+#include "ignition/rendering/ogre/OgreScene.hh"
+#include "ignition/rendering/ogre/OgreMaterial.hh"
+#include "ignition/rendering/ogre/OgreMesh.hh"
+#include "ignition/rendering/ogre/OgreRTShaderSystem.hh"
 
-class gz::rendering::OgreRTShaderSystemPrivate
+class ignition::rendering::OgreRTShaderSystemPrivate
 {
   /// \brief The shader generator.
   public: Ogre::RTShader::ShaderGenerator *shaderGenerator = nullptr;
@@ -70,9 +70,12 @@ class gz::rendering::OgreRTShaderSystemPrivate
 
   /// \brief Flag to indicate shadows need to be reapplied
   public: bool resetShadows = false;
+
+  /// \brief thread that shader system is created in
+  public: std::thread::id threadId;
 };
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -86,12 +89,17 @@ OgreRTShaderSystem::OgreRTShaderSystem()
 #else
   this->dataPtr->pssmSetup.reset();
 #endif
+
+  this->dataPtr->threadId = std::this_thread::get_id();
 }
 
 //////////////////////////////////////////////////
 OgreRTShaderSystem::~OgreRTShaderSystem()
 {
-  this->Fini();
+  if (std::this_thread::get_id() == this->dataPtr->threadId)
+  {
+    this->Fini();
+  }
 }
 
 //////////////////////////////////////////////////
@@ -708,7 +716,7 @@ void OgreRTShaderSystem::Update()
 bool OgreRTShaderSystem::SetShadowTextureSize(const unsigned int _size)
 {
   // check if texture size is a power of 2
-  if (!math::isPowerOfTwo(_size))
+  if (!ignition::math::isPowerOfTwo(_size))
   {
     ignerr << "Shadow texture size must be a power of 2" << std::endl;
     return false;
