@@ -32,43 +32,23 @@
 #endif
 #endif
 
-#include <cstdint>
 #include <math.h>
-#include <gz/math/Helpers.hh>
+#include <ignition/math/Helpers.hh>
 
-#include "gz/rendering/RenderTypes.hh"
-#include "gz/rendering/ogre2/Ogre2Conversions.hh"
-#include "gz/rendering/ogre2/Ogre2DepthCamera.hh"
-#include "gz/rendering/ogre2/Ogre2GaussianNoisePass.hh"
-#include "gz/rendering/ogre2/Ogre2ParticleEmitter.hh"
-#include "gz/rendering/ogre2/Ogre2RenderEngine.hh"
-#include "gz/rendering/ogre2/Ogre2RenderTarget.hh"
-#include "gz/rendering/ogre2/Ogre2RenderTypes.hh"
-#include "gz/rendering/ogre2/Ogre2Scene.hh"
-#include "gz/rendering/ogre2/Ogre2Sensor.hh"
+#include "ignition/rendering/RenderTypes.hh"
+#include "ignition/rendering/ogre2/Ogre2Conversions.hh"
+#include "ignition/rendering/ogre2/Ogre2DepthCamera.hh"
+#include "ignition/rendering/ogre2/Ogre2GaussianNoisePass.hh"
+#include "ignition/rendering/ogre2/Ogre2Includes.hh"
+#include "ignition/rendering/ogre2/Ogre2ParticleEmitter.hh"
+#include "ignition/rendering/ogre2/Ogre2RenderEngine.hh"
+#include "ignition/rendering/ogre2/Ogre2RenderTarget.hh"
+#include "ignition/rendering/ogre2/Ogre2RenderTypes.hh"
+#include "ignition/rendering/ogre2/Ogre2Scene.hh"
+#include "ignition/rendering/ogre2/Ogre2Sensor.hh"
 
 #include "Ogre2ParticleNoiseListener.hh"
 
-#ifdef _MSC_VER
-  #pragma warning(push, 0)
-#endif
-#include <Compositor/OgreCompositorManager2.h>
-#include <Compositor/OgreCompositorWorkspace.h>
-#include <Compositor/Pass/PassClear/OgreCompositorPassClearDef.h>
-#include <Compositor/Pass/PassQuad/OgreCompositorPassQuadDef.h>
-#include <Compositor/Pass/PassScene/OgreCompositorPassSceneDef.h>
-#include <OgreDepthBuffer.h>
-#include <OgreImage2.h>
-#include <OgreParticleSystemManager.h>
-#include <OgreRoot.h>
-#include <OgreSceneManager.h>
-#include <OgreTechnique.h>
-#include <OgreTextureBox.h>
-#include <OgreTextureGpuManager.h>
-#ifdef _MSC_VER
-  #pragma warning(pop)
-#endif
-
 namespace ignition
 {
 namespace rendering
@@ -103,7 +83,7 @@ class Ogre2DepthGaussianNoisePass : public Ogre2GaussianNoisePass
 
 /// \internal
 /// \brief Private data for the Ogre2DepthCamera class
-class gz::rendering::Ogre2DepthCameraPrivate
+class ignition::rendering::Ogre2DepthCameraPrivate
 {
   /// \brief The depth buffer
   public: float *depthBuffer = nullptr;
@@ -115,10 +95,10 @@ class gz::rendering::Ogre2DepthCameraPrivate
   public: float *pointCloudImage = nullptr;
 
   /// \brief maximum value used for data outside sensor range
-  public: float dataMaxVal = gz::math::INF_D;
+  public: float dataMaxVal = ignition::math::INF_D;
 
   /// \brief minimum value used for data outside sensor range
-  public: float dataMinVal = -gz::math::INF_D;
+  public: float dataMinVal = -ignition::math::INF_D;
 
   /// \brief 1st pass compositor workspace definition
   public: std::string ogreCompositorWorkspaceDef;
@@ -151,12 +131,12 @@ class gz::rendering::Ogre2DepthCameraPrivate
   public: bool renderPassDirty = false;
 
   /// \brief Event used to signal rgb point cloud data
-  public: gz::common::EventT<void(const float *,
+  public: ignition::common::EventT<void(const float *,
               unsigned int, unsigned int, unsigned int,
               const std::string &)> newRgbPointCloud;
 
   /// \brief Event used to signal depth data
-  public: gz::common::EventT<void(const float *,
+  public: ignition::common::EventT<void(const float *,
               unsigned int, unsigned int, unsigned int,
               const std::string &)> newDepthFrame;
 
@@ -176,22 +156,9 @@ class gz::rendering::Ogre2DepthCameraPrivate
 
   /// \brief Name of shadow compositor node
   public: const std::string kShadowNodeName = "PbsMaterialsShadowNode";
-
-  /// \brief Execution mask for this workspace
-  /// If RGB point color data are requested, the execution mask of the color
-  /// target will be updated to match the workspace's execution mask so that
-  /// these passes are executed, otherwise they will be skipped for performance
-  /// improvement.
-  public: const uint8_t kDepthExecutionMask = 0xEF;
-
-  /// \brief Pointer to the color target definition in the workspace
-  public: Ogre::CompositorTargetDef *colorTargetDef{nullptr};
-
-  /// \brief Pointer to the particle target definition in the workspace
-  public: Ogre::CompositorTargetDef *particleTargetDef{nullptr};
 };
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -206,9 +173,9 @@ void Ogre2DepthGaussianNoisePass::PreRender()
   if (!this->enabled)
     return;
 
-  Ogre::Vector3 offsets(math::Rand::DblUniform(0.0, 1.0),
-                        math::Rand::DblUniform(0.0, 1.0),
-                        math::Rand::DblUniform(0.0, 1.0));
+  Ogre::Vector3 offsets(ignition::math::Rand::DblUniform(0.0, 1.0),
+                        ignition::math::Rand::DblUniform(0.0, 1.0),
+                        ignition::math::Rand::DblUniform(0.0, 1.0));
 
   Ogre::Pass *pass = this->gaussianNoiseMat->getTechnique(0)->getPass(0);
   Ogre::GpuProgramParametersSharedPtr psParams =
@@ -354,8 +321,6 @@ void Ogre2DepthCamera::Destroy()
   {
     ogreCompMgr->removeWorkspace(
         this->dataPtr->ogreCompositorWorkspace);
-    this->dataPtr->colorTargetDef = nullptr;
-    this->dataPtr->particleTargetDef = nullptr;
   }
 
   if (this->dataPtr->depthMaterial)
@@ -739,27 +704,21 @@ void Ogre2DepthCamera::CreateDepthTexture()
     rtvParticleTexture->depthAttachment.textureName = "particleDepthTexture";
 
     baseNodeDef->setNumTargetPass(4);
-    this->dataPtr->colorTargetDef =
+    Ogre::CompositorTargetDef *colorTargetDef =
         baseNodeDef->addTargetPass("colorTexture");
 
     if (validBackground)
-      this->dataPtr->colorTargetDef->setNumPasses(4);
+      colorTargetDef->setNumPasses(3);
     else
-      this->dataPtr->colorTargetDef->setNumPasses(3);
+      colorTargetDef->setNumPasses(2);
     {
-      // clear pass
-      Ogre::CompositorPassClearDef *passClear =
-          static_cast<Ogre::CompositorPassClearDef *>(
-          this->dataPtr->colorTargetDef->addPass(Ogre::PASS_CLEAR));
-      passClear->mExecutionMask = this->dataPtr->kDepthExecutionMask;
-
       // scene pass - opaque
       {
         Ogre::CompositorPassSceneDef *passScene =
             static_cast<Ogre::CompositorPassSceneDef *>(
-            this->dataPtr->colorTargetDef->addPass(Ogre::PASS_SCENE));
+            colorTargetDef->addPass(Ogre::PASS_SCENE));
         passScene->mShadowNode = this->dataPtr->kShadowNodeName;
-        passScene->setVisibilityMask(IGN_VISIBILITY_ALL);
+        passScene->mVisibilityMask = IGN_VISIBILITY_ALL;
         passScene->mIncludeOverlays = false;
         passScene->mFirstRQ = 0u;
         passScene->mLastRQ = 2u;
@@ -776,7 +735,6 @@ void Ogre2DepthCamera::CreateDepthTexture()
               Ogre2Conversions::Convert(this->Scene()->BackgroundColor()));
 
         }
-        passScene->mExecutionMask = ~this->dataPtr->kDepthExecutionMask;
       }
 
       // render background, e.g. sky, after opaque stuff
@@ -785,25 +743,23 @@ void Ogre2DepthCamera::CreateDepthTexture()
         // quad pass
         Ogre::CompositorPassQuadDef *passQuad =
             static_cast<Ogre::CompositorPassQuadDef *>(
-            this->dataPtr->colorTargetDef->addPass(Ogre::PASS_QUAD));
+            colorTargetDef->addPass(Ogre::PASS_QUAD));
         passQuad->mMaterialName = this->dataPtr->kSkyboxMaterialName + "_"
             + this->Name();
         passQuad->mFrustumCorners =
             Ogre::CompositorPassQuadDef::CAMERA_DIRECTION;
-        passQuad->mExecutionMask = ~this->dataPtr->kDepthExecutionMask;
       }
 
       // scene pass - transparent stuff
       {
         Ogre::CompositorPassSceneDef *passScene =
             static_cast<Ogre::CompositorPassSceneDef *>(
-            this->dataPtr->colorTargetDef->addPass(Ogre::PASS_SCENE));
-        passScene->setVisibilityMask(IGN_VISIBILITY_ALL);
+            colorTargetDef->addPass(Ogre::PASS_SCENE));
+        passScene->mVisibilityMask = IGN_VISIBILITY_ALL;
         // todo(anyone) PbsMaterialsShadowNode is hardcoded.
         // Although this may be just fine
         passScene->mShadowNode = this->dataPtr->kShadowNodeName;
         passScene->mFirstRQ = 2u;
-        passScene->mExecutionMask = ~this->dataPtr->kDepthExecutionMask;
       }
     }
 
@@ -820,36 +776,23 @@ void Ogre2DepthCamera::CreateDepthTexture()
         this->FarClipPlane(),
         this->FarClipPlane(),
         this->FarClipPlane()));
-      // depth texture does not contain particles
-      passScene->setVisibilityMask(
-        IGN_VISIBILITY_ALL & ~Ogre2ParticleEmitter::kParticleVisibilityFlags);
-      passScene->mEnableForwardPlus = false;
-      passScene->setLightVisibilityMask(0x0);
+      // depth texute does not contain particles
+      passScene->mVisibilityMask = IGN_VISIBILITY_ALL
+          & ~Ogre2ParticleEmitter::kParticleVisibilityFlags;
     }
 
-    // Ogre::CompositorTargetDef *particleTargetDef =
-    this->dataPtr->particleTargetDef =
+    Ogre::CompositorTargetDef *particleTargetDef =
         baseNodeDef->addTargetPass("particleTexture");
-    this->dataPtr->particleTargetDef->setNumPasses(2);
+    particleTargetDef->setNumPasses(1);
     {
-      // clear pass
-      Ogre::CompositorPassClearDef *passClear =
-          static_cast<Ogre::CompositorPassClearDef *>(
-          this->dataPtr->particleTargetDef->addPass(Ogre::PASS_CLEAR));
-      passClear->setAllClearColours(Ogre::ColourValue::Black);
-      passClear->mExecutionMask = this->dataPtr->kDepthExecutionMask;
-
       // scene pass
       Ogre::CompositorPassSceneDef *passScene =
           static_cast<Ogre::CompositorPassSceneDef *>(
-          this->dataPtr->particleTargetDef->addPass(Ogre::PASS_SCENE));
+          particleTargetDef->addPass(Ogre::PASS_SCENE));
       passScene->setAllLoadActions(Ogre::LoadAction::Clear);
       passScene->setAllClearColours(Ogre::ColourValue::Black);
-      passScene->setVisibilityMask(
-        Ogre2ParticleEmitter::kParticleVisibilityFlags);
-      passScene->mEnableForwardPlus = false;
-      passScene->setLightVisibilityMask(0x0);
-      passScene->mExecutionMask = ~this->dataPtr->kDepthExecutionMask;
+      passScene->mVisibilityMask =
+          Ogre2ParticleEmitter::kParticleVisibilityFlags;
     }
 
     // rt0 target - converts depth to xyz
@@ -973,13 +916,13 @@ void Ogre2DepthCamera::CreateDepthTexture()
         this->ImageWidth(), this->ImageHeight());
       this->dataPtr->ogreDepthTexture[i]->setNumMipmaps(1u);
       this->dataPtr->ogreDepthTexture[i]->setPixelFormat(
-        Ogre::PFG_RGBA32_UINT);
+        Ogre::PFG_RGBA32_FLOAT);
 
       this->dataPtr->ogreDepthTexture[i]->scheduleTransitionTo(
         Ogre::GpuResidency::Resident);
   }
 
-  this->CreateWorkspaceInstance();
+  CreateWorkspaceInstance();
 }
 
 //////////////////////////////////////////////////
@@ -1001,8 +944,7 @@ void Ogre2DepthCamera::CreateWorkspaceInstance()
           externalTargets,
           this->ogreCamera,
           this->dataPtr->ogreCompositorWorkspaceDef,
-          false, -1, 0, 0, 0, Ogre::Vector4::ZERO, 0x00,
-          this->dataPtr->kDepthExecutionMask);
+          false);
 
   this->dataPtr->ogreCompositorWorkspace->addListener(
     engine->TerraWorkspaceListener());
@@ -1071,51 +1013,6 @@ void Ogre2DepthCamera::PreRender()
   if (!this->dataPtr->ogreCompositorWorkspace)
     this->CreateWorkspaceInstance();
 
-
-  // Disable color target (set to clear pass) if there are no rgb point cloud
-  // connections
-  if (this->dataPtr->colorTargetDef)
-  {
-    Ogre::CompositorPassDefVec &colorPasses =
-        this->dataPtr->colorTargetDef->getCompositorPassesNonConst();
-    IGN_ASSERT(colorPasses.size() > 2u,
-        "Ogre2DepthCamera color target should contain more than 2 passes");
-    IGN_ASSERT(colorPasses[0]->getType() == Ogre::PASS_CLEAR,
-        "Ogre2DepthCamera color target should start with a clear pass");
-    colorPasses[0]->mExecutionMask =
-      (this->dataPtr->newRgbPointCloud.ConnectionCount() > 0u) ?
-      ~this->dataPtr->kDepthExecutionMask :this->dataPtr->kDepthExecutionMask;
-    for (unsigned int i = 1; i < colorPasses.size(); ++i)
-    {
-      colorPasses[i]->mExecutionMask =
-          (this->dataPtr->newRgbPointCloud.ConnectionCount() > 0u) ?
-          this->dataPtr->kDepthExecutionMask :
-          ~this->dataPtr->kDepthExecutionMask;
-    }
-  }
-
-  // Disable particle target (set to clear pass) if there are no particles
-  if (this->dataPtr->particleTargetDef)
-  {
-    bool hasParticles =
-        this->scene->OgreSceneManager()->getMovableObjectIterator(
-        Ogre::ParticleSystemFactory::FACTORY_TYPE_NAME).hasMoreElements();
-    Ogre::CompositorPassDefVec &particlePasses =
-        this->dataPtr->particleTargetDef->getCompositorPassesNonConst();
-    IGN_ASSERT(particlePasses.size() == 2u,
-        "Ogre2DepthCamera particle target should 2 passes");
-    IGN_ASSERT(particlePasses[0]->getType() == Ogre::PASS_CLEAR,
-        "Ogre2DepthCamera particle target should start with a clear pass");
-    IGN_ASSERT(particlePasses[1]->getType() == Ogre::PASS_SCENE,
-        "Ogre2DepthCamera particle target should end with a scene pass");
-    particlePasses[0]->mExecutionMask =
-      (hasParticles) ? ~this->dataPtr->kDepthExecutionMask :
-                       this->dataPtr->kDepthExecutionMask;
-    particlePasses[1]->mExecutionMask =
-      (hasParticles) ? this->dataPtr->kDepthExecutionMask :
-                       ~this->dataPtr->kDepthExecutionMask;
-  }
-
   // update depth camera render passes
   Ogre2RenderTarget::UpdateRenderPassChain(
       this->dataPtr->ogreCompositorWorkspace,
@@ -1271,7 +1168,7 @@ const float *Ogre2DepthCamera::DepthData() const
 }
 
 //////////////////////////////////////////////////
-common::ConnectionPtr Ogre2DepthCamera::ConnectNewDepthFrame(
+ignition::common::ConnectionPtr Ogre2DepthCamera::ConnectNewDepthFrame(
     std::function<void(const float *, unsigned int, unsigned int,
       unsigned int, const std::string &)>  _subscriber)
 {
@@ -1279,7 +1176,7 @@ common::ConnectionPtr Ogre2DepthCamera::ConnectNewDepthFrame(
 }
 
 //////////////////////////////////////////////////
-common::ConnectionPtr Ogre2DepthCamera::ConnectNewRgbPointCloud(
+ignition::common::ConnectionPtr Ogre2DepthCamera::ConnectNewRgbPointCloud(
     std::function<void(const float *, unsigned int, unsigned int,
       unsigned int, const std::string &)>  _subscriber)
 {
