@@ -15,23 +15,23 @@
  *
 */
 
-#include <gz/math/Vector2.hh>
-#include <gz/math/Vector3.hh>
+#include <ignition/math/Vector2.hh>
+#include <ignition/math/Vector3.hh>
 
-#include <gz/common/Console.hh>
-#include <gz/math/Helpers.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/math/Helpers.hh>
 
-#include "gz/rendering/ogre2/Ogre2Camera.hh"
-#include "gz/rendering/ogre2/Ogre2GpuRays.hh"
-#include "gz/rendering/ogre2/Ogre2RenderEngine.hh"
-#include "gz/rendering/RenderTypes.hh"
-#include "gz/rendering/ogre2/Ogre2Conversions.hh"
-#include "gz/rendering/ogre2/Ogre2ParticleEmitter.hh"
-#include "gz/rendering/ogre2/Ogre2RenderTarget.hh"
-#include "gz/rendering/ogre2/Ogre2RenderTypes.hh"
-#include "gz/rendering/ogre2/Ogre2Scene.hh"
-#include "gz/rendering/ogre2/Ogre2Sensor.hh"
-#include "gz/rendering/ogre2/Ogre2Visual.hh"
+#include "ignition/rendering/ogre2/Ogre2Camera.hh"
+#include "ignition/rendering/ogre2/Ogre2GpuRays.hh"
+#include "ignition/rendering/ogre2/Ogre2RenderEngine.hh"
+#include "ignition/rendering/RenderTypes.hh"
+#include "ignition/rendering/ogre2/Ogre2Conversions.hh"
+#include "ignition/rendering/ogre2/Ogre2ParticleEmitter.hh"
+#include "ignition/rendering/ogre2/Ogre2RenderTarget.hh"
+#include "ignition/rendering/ogre2/Ogre2RenderTypes.hh"
+#include "ignition/rendering/ogre2/Ogre2Scene.hh"
+#include "ignition/rendering/ogre2/Ogre2Sensor.hh"
+#include "ignition/rendering/ogre2/Ogre2Visual.hh"
 
 #include "Ogre2IgnHlmsCustomizations.hh"
 #include "Ogre2ParticleNoiseListener.hh"
@@ -42,18 +42,13 @@
 #endif
 #include <Compositor/OgreCompositorManager2.h>
 #include <Compositor/OgreCompositorWorkspace.h>
-#include <Compositor/Pass/PassClear/OgreCompositorPassClearDef.h>
 #include <Compositor/Pass/PassQuad/OgreCompositorPassQuadDef.h>
 #include <Compositor/Pass/PassScene/OgreCompositorPassSceneDef.h>
 #include <OgreDepthBuffer.h>
-#include <OgreHlms.h>
 #include <OgreItem.h>
-#include <OgrePixelFormatGpuUtils.h>
 #include <OgreRoot.h>
 #include <OgreSceneManager.h>
-#include <OgreStagingTexture.h>
 #include <OgreTechnique.h>
-#include <OgreTextureGpuManager.h>
 #ifdef _MSC_VER
   #pragma warning(pop)
 #endif
@@ -109,7 +104,7 @@ class Ogre2LaserRetroMaterialSwitcher : public Ogre::Camera::Listener
 
 /// \internal
 /// \brief Private data for the Ogre2GpuRays class
-class gz::rendering::Ogre2GpuRaysPrivate
+class ignition::rendering::Ogre2GpuRaysPrivate
 {
   /// \brief Event triggered when new gpu rays range data are available.
   /// \param[in] _frame New frame containing raw gpu rays data.
@@ -117,7 +112,7 @@ class gz::rendering::Ogre2GpuRaysPrivate
   /// \param[in] _height Height of frame.
   /// \param[in] _channel Number of channels
   /// \param[in] _format Format of frame.
-  public: gz::common::EventT<void(const float *,
+  public: ignition::common::EventT<void(const float *,
                unsigned int, unsigned int, unsigned int,
                const std::string &)> newGpuRaysFrame;
 
@@ -205,19 +200,9 @@ class gz::rendering::Ogre2GpuRaysPrivate
   /// \brief Max number of cameras used for creating the cubemap of depth
   /// textures for generating lidar data
   public: const unsigned int kCubeCameraCount = 6;
-
-  /// \brief Execution mask for this workspace
-  /// If particles exist in the scene, the execution mask of the particle
-  /// target will be updated to match the workspace's execution mask so that
-  /// these passes are executed, otherwise they will be skipped for performance
-  /// improvement.
-  public: const uint8_t kGpuRaysExecutionMask = 0xEF;
-
-  /// \brief Pointer to the particle target definition in the workspace
-  public: Ogre::CompositorTargetDef *particleTargetDef{nullptr};
 };
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 //////////////////////////////////////////////////
@@ -422,24 +407,30 @@ void Ogre2GpuRays::Destroy()
 
   auto engine = Ogre2RenderEngine::Instance();
   auto ogreRoot = engine->OgreRoot();
+  if (this->dataPtr->cubeUVTexture)
+  {
+    ogreRoot->getRenderSystem()->getTextureGpuManager()->destroyTexture(
+      this->dataPtr->cubeUVTexture);
+    this->dataPtr->cubeUVTexture = nullptr;
+  }
 
   Ogre::CompositorManager2 *ogreCompMgr = ogreRoot->getCompositorManager2();
 
   // remove 1st pass textures, material, compositors
   for (auto i : this->dataPtr->cubeFaceIdx)
   {
-    if (this->dataPtr->ogreCompositorWorkspace1st[i])
-    {
-      ogreCompMgr->removeWorkspace(
-          this->dataPtr->ogreCompositorWorkspace1st[i]);
-      this->dataPtr->ogreCompositorWorkspace1st[i] = nullptr;
-    }
     if (this->dataPtr->firstPassTextures[i])
     {
       ogreRoot->getRenderSystem()->getTextureGpuManager()->destroyTexture(
          this->dataPtr->firstPassTextures[i]);
       this->dataPtr->firstPassTextures[i] = nullptr;
     }
+    if (this->dataPtr->ogreCompositorWorkspace1st[i])
+    {
+      ogreCompMgr->removeWorkspace(
+          this->dataPtr->ogreCompositorWorkspace1st[i]);
+      this->dataPtr->ogreCompositorWorkspace1st[i] = nullptr;
+    }
   }
   if (this->dataPtr->matFirstPass)
   {
@@ -456,7 +447,6 @@ void Ogre2GpuRays::Destroy()
         this->dataPtr->ogreCompositorNodeDef1st);
     this->dataPtr->ogreCompositorWorkspaceDef1st.clear();
   }
-  this->dataPtr->particleTargetDef = nullptr;
 
   // remove 2nd pass texture, material, compositor
   if (this->dataPtr->secondPassTexture)
@@ -483,13 +473,6 @@ void Ogre2GpuRays::Destroy()
     this->dataPtr->ogreCompositorWorkspaceDef2nd.clear();
   }
 
-  auto textureGpuManager = ogreRoot->getRenderSystem()->getTextureGpuManager();
-  if (this->dataPtr->cubeUVTexture)
-  {
-    textureGpuManager->destroyTexture(this->dataPtr->cubeUVTexture);
-    this->dataPtr->cubeUVTexture = nullptr;
-  }
-
   if (this->scene)
   {
     Ogre::SceneManager *ogreSceneManager = this->scene->OgreSceneManager();
@@ -977,36 +960,24 @@ void Ogre2GpuRays::Setup1stPass()
           colorTargetDef->addPass(Ogre::PASS_SCENE));
       passScene->setAllLoadActions(Ogre::LoadAction::Clear);
       passScene->setAllClearColours(Ogre::ColourValue(0, 0, 0));
-      passScene->setVisibilityMask(
-        this->VisibilityMask() &
-        ~Ogre2ParticleEmitter::kParticleVisibilityFlags);
-      passScene->mEnableForwardPlus = false;
-      passScene->setLightVisibilityMask(0x0);
+      // set camera custom visibility mask when rendering laser retro
+      passScene->mVisibilityMask = this->VisibilityMask() &
+          ~Ogre2ParticleEmitter::kParticleVisibilityFlags;
     }
 
-    this->dataPtr->particleTargetDef =
+    Ogre::CompositorTargetDef *particleTargetDef =
         nodeDef->addTargetPass("particleTexture");
-    this->dataPtr->particleTargetDef->setNumPasses(2);
+    particleTargetDef->setNumPasses(1);
     {
-      // clear pass
-      Ogre::CompositorPassClearDef *passClear =
-          static_cast<Ogre::CompositorPassClearDef *>(
-          this->dataPtr->particleTargetDef->addPass(Ogre::PASS_CLEAR));
-      passClear->setAllClearColours(Ogre::ColourValue::Black);
-      passClear->mExecutionMask = this->dataPtr->kGpuRaysExecutionMask;
-
       // scene pass
       Ogre::CompositorPassSceneDef *passScene =
           static_cast<Ogre::CompositorPassSceneDef *>(
-          this->dataPtr->particleTargetDef->addPass(Ogre::PASS_SCENE));
+          particleTargetDef->addPass(Ogre::PASS_SCENE));
       passScene->setAllLoadActions(Ogre::LoadAction::Clear);
       passScene->setAllClearColours(Ogre::ColourValue::Black);
       // set camera custom visibility mask when rendering particles
       passScene->mVisibilityMask =
           Ogre2ParticleEmitter::kParticleVisibilityFlags;
-      passScene->mEnableForwardPlus = false;
-      passScene->setLightVisibilityMask(0x0);
-      passScene->mExecutionMask = 0x0;
     }
 
     // rt_input target - converts depth to range
@@ -1101,8 +1072,7 @@ void Ogre2GpuRays::Setup1stPass()
           this->dataPtr->firstPassTextures[i],
           this->dataPtr->cubeCam[i],
           wsDefName,
-          false, -1, 0, 0, 0, Ogre::Vector4::ZERO, 0x00,
-          this->dataPtr->kGpuRaysExecutionMask);
+          false);
 
     Ogre::CompositorNode *node =
         this->dataPtr->ogreCompositorWorkspace1st[i]->getNodeSequence()[0];
@@ -1362,27 +1332,6 @@ void Ogre2GpuRays::PreRender()
 {
   if (!this->dataPtr->cubeUVTexture)
     this->CreateGpuRaysTextures();
-
-  if (this->dataPtr->particleTargetDef)
-  {
-    bool hasParticles =
-        this->scene->OgreSceneManager()->getMovableObjectIterator(
-        Ogre::ParticleSystemFactory::FACTORY_TYPE_NAME).hasMoreElements();
-    Ogre::CompositorPassDefVec &particlePasses =
-        this->dataPtr->particleTargetDef->getCompositorPassesNonConst();
-    IGN_ASSERT(particlePasses.size() == 2u,
-        "Ogre2DepthCamera particle target should 2 passes");
-    IGN_ASSERT(particlePasses[0]->getType() == Ogre::PASS_CLEAR,
-        "Ogre2DepthCamera particle target should start with a clear pass");
-    IGN_ASSERT(particlePasses[1]->getType() == Ogre::PASS_SCENE,
-        "Ogre2DepthCamera particle target should end with a scene pass");
-    particlePasses[0]->mExecutionMask =
-      (hasParticles) ? ~this->dataPtr->kGpuRaysExecutionMask :
-                       this->dataPtr->kGpuRaysExecutionMask;
-    particlePasses[1]->mExecutionMask =
-      (hasParticles) ? this->dataPtr->kGpuRaysExecutionMask :
-                       ~this->dataPtr->kGpuRaysExecutionMask;
-  }
 }
 
 //////////////////////////////////////////////////
@@ -1502,7 +1451,7 @@ void Ogre2GpuRays::SetRangeCount(
 }
 
 //////////////////////////////////////////////////
-common::ConnectionPtr Ogre2GpuRays::ConnectNewGpuRaysFrame(
+ignition::common::ConnectionPtr Ogre2GpuRays::ConnectNewGpuRaysFrame(
     std::function<void(const float *_frame, unsigned int _width,
     unsigned int _height, unsigned int _channels,
     const std::string &/*_format*/)> _subscriber)
