@@ -37,14 +37,12 @@
 #include <Compositor/Pass/PassScene/OgreCompositorPassSceneDef.h>
 #include <OgreCamera.h>
 #include <OgreDepthBuffer.h>
-#include <OgreHardwarePixelBuffer.h>
 #include <OgreItem.h>
 #include <OgrePass.h>
-#include <OgreRenderTexture.h>
 #include <OgreRoot.h>
 #include <OgreSceneManager.h>
 #include <OgreTechnique.h>
-#include <OgreTextureManager.h>
+#include <OgreTextureGpuManager.h>
 #include <OgreViewport.h>
 #ifdef _MSC_VER
   #pragma warning(pop)
@@ -74,22 +72,24 @@ class ignition::rendering::Ogre2SelectionBufferPrivate
   /// \brief Selection buffer's render to texture camera
   public: Ogre::Camera *selectionCamera  = nullptr;
 
-  /// \brief Ogre texture
-  public: Ogre::TexturePtr texture;
-
   /// \brief Ogre render texture
-  // public: Ogre2RenderTexturePtr renderTexture;
-  public: Ogre::RenderTexture *renderTexture = nullptr;
+  public: Ogre::TextureGpu *renderTexture = nullptr;
+
+  /// \brief Ogre compositor manager
+  public: Ogre::CompositorManager2 *ogreCompMgr = nullptr;
+
+  /// \brief selection buffer width
+  public: unsigned int width = 0;
+
+  /// \brief selection buffer height
+  public: unsigned int height = 0;
 
   /// \brief Ogre's compositor workspace - the main interface to render
   /// into a render target or render texture.
   public: Ogre::CompositorWorkspace *ogreCompositorWorkspace = nullptr;
 
-  /// \brief Render texture data buffer
-  public: float *buffer = nullptr;
-
-  /// \brief Ogre pixel box that contains description of the data buffer
-  public: Ogre::PixelBox *pixelBox = nullptr;
+  /// \brief Name of the compositor workspace definition
+  public: std::string ogreCompWorkspaceDefName;
 
   /// \brief The selection buffer material
   public: Ogre::MaterialPtr selectionMaterial;
@@ -97,11 +97,19 @@ class ignition::rendering::Ogre2SelectionBufferPrivate
 
 /////////////////////////////////////////////////
 Ogre2SelectionBuffer::Ogre2SelectionBuffer(const std::string &_cameraName,
-    Ogre2ScenePtr _scene): dataPtr(new Ogre2SelectionBufferPrivate)
+    Ogre2ScenePtr _scene, unsigned int _width, unsigned int _height):
+    dataPtr(new Ogre2SelectionBufferPrivate)
 {
   this->dataPtr->scene = _scene;
   this->dataPtr->sceneMgr = _scene->OgreSceneManager();
 
+  auto engine = Ogre2RenderEngine::Instance();
+  auto ogreRoot = engine->OgreRoot();
+  this->dataPtr->ogreCompMgr = ogreRoot->getCompositorManager2();
+
+  this->dataPtr->width = _width;
+  this->dataPtr->height = _height;
+
   this->dataPtr->camera = this->dataPtr->sceneMgr->findCameraNoThrow(
       _cameraName);
   if (!this->dataPtr->camera)
@@ -115,6 +123,18 @@ Ogre2SelectionBuffer::Ogre2SelectionBuffer(const std::string &_cameraName,
   this->dataPtr->selectionCamera =
       this->dataPtr->sceneMgr->createCamera(selectionCameraName);
 
+  this->dataPtr->selectionCamera->detachFromParent();
+  this->dataPtr->sceneMgr->getRootSceneNode()->attachObject(
+    this->dataPtr->selectionCamera);
+
+  this->dataPtr->selectionCamera->setFOVy(this->dataPtr->camera->getFOVy());
+  this->dataPtr->selectionCamera->setNearClipDistance(
+    this->dataPtr->camera->getNearClipDistance());
+  this->dataPtr->selectionCamera->setFarClipDistance(
+     this->dataPtr->camera->getFarClipDistance());
+  this->dataPtr->selectionCamera->setAspectRatio(
+    this->dataPtr->camera->getAspectRatio());
+
   this->dataPtr->materialSwitcher.reset(
       new Ogre2MaterialSwitcher(this->dataPtr->scene));
   this->CreateRTTBuffer();
@@ -125,6 +145,16 @@ Ogre2SelectionBuffer::~Ogre2SelectionBuffer()
 {
   this->DeleteRTTBuffer();
 
+  // remove selectionMaterial in destructor
+  // this does not need to be done in DeleteRTTBuffer as we do not need to
+  // reload the same material every time
+  if (!this->dataPtr->selectionMaterial.isNull())
+  {
+    Ogre::MaterialManager::getSingleton().remove(
+        this->dataPtr->selectionMaterial->getName());
+    this->dataPtr->selectionMaterial.setNull();
+  }
+
   // remove selection buffer camera
   this->dataPtr->sceneMgr->destroyCamera(this->dataPtr->selectionCamera);
 }
@@ -137,63 +167,99 @@ void Ogre2SelectionBuffer::Update()
 
   this->dataPtr->materialSwitcher->Reset();
 
-  // manual update
-  this->dataPtr->ogreCompositorWorkspace->setEnabled(true);
-  auto engine = Ogre2RenderEngine::Instance();
-  engine->OgreRoot()->renderOneFrame();
-  this->dataPtr->ogreCompositorWorkspace->setEnabled(false);
+  this->dataPtr->scene->StartForcedRender();
 
-  this->dataPtr->renderTexture->copyContentsToMemory(*this->dataPtr->pixelBox,
-      Ogre::RenderTarget::FB_FRONT);
+  // manual update
+  // this->dataPtr->ogreCompositorWorkspace->setEnabled(true);
+  // auto engine = Ogre2RenderEngine::Instance();
+  // engine->OgreRoot()->renderOneFrame();
+  // this->dataPtr->ogreCompositorWorkspace->setEnabled(false);
+  this->dataPtr->ogreCompositorWorkspace->_validateFinalTarget();
+  this->dataPtr->ogreCompositorWorkspace->_beginUpdate(false);
+  this->dataPtr->ogreCompositorWorkspace->_update();
+  this->dataPtr->ogreCompositorWorkspace->_endUpdate(false);
+
+  Ogre::vector<Ogre::TextureGpu *>::type swappedTargets;
+  swappedTargets.reserve(2u);
+  this->dataPtr->ogreCompositorWorkspace->_swapFinalTarget(swappedTargets);
+
+  this->dataPtr->scene->FlushGpuCommandsAndStartNewFrame(1u, false);
+
+  this->dataPtr->scene->EndForcedRender();
+
+  // this->dataPtr->renderTexture->copyContentsToMemory(*this->dataPtr->pixelBox,
+  //     Ogre::RenderTarget::FB_FRONT);
 }
 
 /////////////////////////////////////////////////
 void Ogre2SelectionBuffer::DeleteRTTBuffer()
 {
-  if (this->dataPtr->selectionMaterial)
+  if (this->dataPtr->ogreCompositorWorkspace)
   {
-    Ogre::MaterialManager::getSingleton().remove(
-        this->dataPtr->selectionMaterial->getName());
+    // TODO(ahcorde): Remove the workspace. Potential leak here
+    this->dataPtr->ogreCompMgr->removeWorkspace(
+        this->dataPtr->ogreCompositorWorkspace);
+
+    this->dataPtr->ogreCompMgr->removeWorkspaceDefinition(
+        this->dataPtr->ogreCompWorkspaceDefName);
+    this->dataPtr->ogreCompMgr->removeNodeDefinition(
+        this->dataPtr->ogreCompWorkspaceDefName + "/Node");
+    this->dataPtr->ogreCompositorWorkspace = nullptr;
   }
 
-  auto &manager = Ogre::TextureManager::getSingleton();
-  manager.unload(this->dataPtr->texture->getName());
-  manager.remove(this->dataPtr->texture->getName());
-
-  if (this->dataPtr->buffer)
-  {
-    delete [] this->dataPtr->buffer;
-    this->dataPtr->buffer = nullptr;
-  }
-  if (this->dataPtr->pixelBox)
-    delete this->dataPtr->pixelBox;
+  auto engine = Ogre2RenderEngine::Instance();
+  auto ogreRoot = engine->OgreRoot();
+  ogreRoot->getRenderSystem()->getTextureGpuManager()->destroyTexture(
+    this->dataPtr->renderTexture);
+  this->dataPtr->renderTexture = nullptr;
 }
 
 /////////////////////////////////////////////////
 void Ogre2SelectionBuffer::CreateRTTBuffer()
 {
-  // create a 1x1 pixel buffer
-  unsigned int width = 1;
-  unsigned int height = 1;
-  Ogre::PixelFormat format = Ogre::PF_FLOAT32_RGBA;
-  this->dataPtr->texture = Ogre::TextureManager::getSingleton().createManual(
-        "SelectionPassTex",
-        Ogre::ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME,
-        Ogre::TEX_TYPE_2D, width, height, 0, Ogre::PF_FLOAT32_RGBA,
-        Ogre::TU_RENDERTARGET);
+  auto engine = Ogre2RenderEngine::Instance();
+  auto ogreRoot = engine->OgreRoot();
 
+  Ogre::TextureGpuManager *textureMgr =
+    ogreRoot->getRenderSystem()->getTextureGpuManager();
+  const std::string selectionTextureName = "SelectionPassTex";
+  bool hasSelectionTexture =
+      textureMgr->findTextureNoThrow(selectionTextureName);
   this->dataPtr->renderTexture =
-      this->dataPtr->texture->getBuffer()->getRenderTarget();
+      textureMgr->createOrRetrieveTexture(
+        selectionTextureName,
+        Ogre::GpuPageOutStrategy::SaveToSystemRam,
+        Ogre::TextureFlags::RenderToTexture,
+        Ogre::TextureTypes::Type2D);
+  if (!hasSelectionTexture)
+  {
+    this->dataPtr->renderTexture->setResolution(1, 1);
+    this->dataPtr->renderTexture->setNumMipmaps(1u);
+    this->dataPtr->renderTexture->setPixelFormat(Ogre::PFG_RGBA32_FLOAT);
+
+    // we are reusing the same render texture so schedule transition only
+    // if it is not resident yet otherwise it may throw an exception
+    this->dataPtr->renderTexture->scheduleTransitionTo(
+      Ogre::GpuResidency::Resident);
+  }
+
+  this->dataPtr->selectionCamera->addListener(
+      this->dataPtr->materialSwitcher.get());
 
   // Load selection material
   // The SelectionBuffer material is defined in script
   // (selection_buffer.material).
   std::string matSelectionName = "SelectionBuffer";
-  Ogre::MaterialPtr matSelection =
-      Ogre::MaterialManager::getSingleton().getByName(matSelectionName);
-  this->dataPtr->selectionMaterial = matSelection->clone(
-      this->dataPtr->camera->getName() + "_" + matSelectionName);
-  this->dataPtr->selectionMaterial->load();
+  std::string matSelectionCloneName =
+      this->dataPtr->camera->getName() + "_" + matSelectionName;
+  if (this->dataPtr->selectionMaterial.isNull())
+  {
+    Ogre::MaterialPtr matSelection =
+        Ogre::MaterialManager::getSingleton().getByName(matSelectionName);
+    this->dataPtr->selectionMaterial = matSelection->clone(
+        matSelectionCloneName);
+    this->dataPtr->selectionMaterial->load();
+  }
   Ogre::Pass *p = this->dataPtr->selectionMaterial->getTechnique(0)->getPass(0);
   Ogre::GpuProgramParametersSharedPtr psParams =
       p->getFragmentProgramParameters();
@@ -202,21 +268,13 @@ void Ogre2SelectionBuffer::CreateRTTBuffer()
   // The projectParams is used to linearize depth buffer data
   double nearPlane = this->dataPtr->camera->getNearClipDistance();
   double farPlane = this->dataPtr->camera->getFarClipDistance();
-
   this->dataPtr->selectionCamera->setNearClipDistance(nearPlane);
   this->dataPtr->selectionCamera->setFarClipDistance(farPlane);
 
-  // \todo(anyone) change the code below when merging forward to fortress that
-  // uses ogre 2.2 otherwise the depth values will be incorrect due to
-  // reverse-z depth buffer
-  // Ogre::Vector2 projectionAB =
-  //   this->dataPtr->camera->getProjectionParamsAB();
-  // double projectionA = projectionAB.x
-  // double projectionB = projectionAB.y
-  double projectionA = farPlane /
-      (farPlane - nearPlane);
-  double projectionB = (-farPlane * nearPlane) /
-      (farPlane - nearPlane);
+  Ogre::Vector2 projectionAB =
+    this->dataPtr->selectionCamera->getProjectionParamsAB();
+  double projectionA = projectionAB.x;
+  double projectionB = projectionAB.y;
   projectionB /= farPlane;
   psParams->setNamedConstant("projectionParams",
       Ogre::Vector2(projectionA, projectionB));
@@ -226,52 +284,53 @@ void Ogre2SelectionBuffer::CreateRTTBuffer()
       static_cast<float>(math::INF_F));
 
   // create compositor workspace for rendering
-  auto engine = Ogre2RenderEngine::Instance();
-  auto ogreRoot = engine->OgreRoot();
-  Ogre::CompositorManager2 *ogreCompMgr = ogreRoot->getCompositorManager2();
-
-  const Ogre::String workspaceName = "SelectionBufferWorkspace" +
+  // Setup the selection buffer compositor.
+  this->dataPtr->ogreCompWorkspaceDefName = "SelectionBufferWorkspace" +
       this->dataPtr->camera->getName();
 
+  std::string nodeSpaceDefName =
+      this->dataPtr->ogreCompWorkspaceDefName + "/Node";
+
   Ogre::CompositorNodeDef *nodeDef =
-      ogreCompMgr->addNodeDefinition("AutoGen " + Ogre::IdString(workspaceName +
-      "/Node").getReleaseText());
-
-  Ogre::TextureDefinitionBase::TextureDefinition *colorTexDef =
-      nodeDef->addTextureDefinition("colorTexture");
-  colorTexDef->textureType = Ogre::TEX_TYPE_2D;
-  colorTexDef->width = 0;
-  colorTexDef->height = 0;
-  colorTexDef->depth = 1;
-  colorTexDef->numMipmaps = 0;
-  colorTexDef->widthFactor = 1;
-  colorTexDef->heightFactor = 1;
-  colorTexDef->formatList = {Ogre::PF_FLOAT32_RGBA};
-  colorTexDef->fsaa = 0;
-  colorTexDef->uav = false;
-  colorTexDef->automipmaps = false;
-  colorTexDef->depthBufferId = Ogre::DepthBuffer::POOL_DEFAULT;
-  colorTexDef->depthBufferFormat = Ogre::PF_D32_FLOAT;
-  colorTexDef->preferDepthTexture = true;
-  colorTexDef->fsaaExplicitResolve = false;
-
+      this->dataPtr->ogreCompMgr->addNodeDefinition(
+      nodeSpaceDefName);
   Ogre::TextureDefinitionBase::TextureDefinition *depthTexDef =
       nodeDef->addTextureDefinition("depthTexture");
-  depthTexDef->textureType = Ogre::TEX_TYPE_2D;
+  depthTexDef->textureType = Ogre::TextureTypes::Type2D;
   depthTexDef->width = 0;
   depthTexDef->height = 0;
-  depthTexDef->depth = 1;
+  depthTexDef->depthOrSlices = 1;
   depthTexDef->numMipmaps = 0;
   depthTexDef->widthFactor = 1;
   depthTexDef->heightFactor = 1;
-  depthTexDef->formatList = {Ogre::PF_D32_FLOAT};
-  depthTexDef->fsaa = 0;
-  depthTexDef->uav = false;
-  depthTexDef->automipmaps = false;
-  depthTexDef->hwGammaWrite = Ogre::TextureDefinitionBase::BoolFalse;
+  depthTexDef->format = Ogre::PFG_D32_FLOAT;
+  depthTexDef->textureFlags &= ~Ogre::TextureFlags::Uav;
   depthTexDef->depthBufferId = Ogre::DepthBuffer::POOL_DEFAULT;
-  depthTexDef->depthBufferFormat = Ogre::PF_UNKNOWN;
-  depthTexDef->fsaaExplicitResolve = false;
+  depthTexDef->depthBufferFormat = Ogre::PFG_UNKNOWN;
+  depthTexDef->fsaa = "0";
+
+  Ogre::TextureDefinitionBase::TextureDefinition *colorTexDef =
+      nodeDef->addTextureDefinition("colorTexture");
+  colorTexDef->textureType = Ogre::TextureTypes::Type2D;
+  colorTexDef->width = 0;
+  colorTexDef->height = 0;
+  colorTexDef->depthOrSlices = 1;
+  colorTexDef->numMipmaps = 0;
+  colorTexDef->widthFactor = 1;
+  colorTexDef->heightFactor = 1;
+  colorTexDef->format = Ogre::PFG_RGBA8_UNORM;
+  colorTexDef->textureFlags &= ~Ogre::TextureFlags::Uav;
+  colorTexDef->depthBufferId = Ogre::DepthBuffer::POOL_DEFAULT;
+  colorTexDef->depthBufferFormat = Ogre::PFG_D32_FLOAT;
+  colorTexDef->preferDepthTexture = true;
+  colorTexDef->fsaa = "0";
+
+  // Auto setup the RTV then manually override the depth buffer so
+  // it uses the one we created (and thus we can sample from it later)
+  Ogre::RenderTargetViewDef *rtvColor =
+    nodeDef->addRenderTextureView("colorTexture");
+  rtvColor->setForTextureDefinition("colorTexture", colorTexDef);
+  rtvColor->depthAttachment.textureName = "depthTexture";
 
   // Input texture
   nodeDef->addTextureSourceName("rt", 0,
@@ -280,74 +339,60 @@ void Ogre2SelectionBuffer::CreateRTTBuffer()
   nodeDef->setNumTargetPass(2);
   Ogre::CompositorTargetDef *colorTargetDef =
       nodeDef->addTargetPass("colorTexture");
-  colorTargetDef->setNumPasses(2);
+  colorTargetDef->setNumPasses(1);
   {
-    // clear pass
-    Ogre::CompositorPassClearDef *passClear =
-        static_cast<Ogre::CompositorPassClearDef *>(
-        colorTargetDef->addPass(Ogre::PASS_CLEAR));
-    passClear->mColourValue = Ogre::ColourValue(0.0f, 0.0f, 0.0f, 1.0f);
     // scene pass
     Ogre::CompositorPassSceneDef *passScene =
         static_cast<Ogre::CompositorPassSceneDef *>(
         colorTargetDef->addPass(Ogre::PASS_SCENE));
+    passScene->setAllLoadActions(Ogre::LoadAction::Clear);
+    passScene->setAllClearColours(Ogre::ColourValue::Black);
     passScene->mVisibilityMask = IGN_VISIBILITY_SELECTABLE;
   }
 
   Ogre::CompositorTargetDef *targetDef = nodeDef->addTargetPass("rt");
-  targetDef->setNumPasses(2);
+  targetDef->setNumPasses(1);
   {
-    {
-      Ogre::CompositorPassClearDef *passClear =
-          static_cast<Ogre::CompositorPassClearDef *>(
-          targetDef->addPass(Ogre::PASS_CLEAR));
-      passClear->mColourValue = Ogre::ColourValue(0.0f, 0.0f, 0.0f, 1.0f);
-    }
     // quad pass
     Ogre::CompositorPassQuadDef *passQuad =
         static_cast<Ogre::CompositorPassQuadDef *>(
         targetDef->addPass(Ogre::PASS_QUAD));
+    passQuad->setAllLoadActions(Ogre::LoadAction::Clear);
+    passQuad->setAllClearColours(Ogre::ColourValue::Black);
     passQuad->mMaterialName = this->dataPtr->selectionMaterial->getName();
-    passQuad->addQuadTextureSource(0, "colorTexture", 0);
-    passQuad->addQuadTextureSource(1, "depthTexture", 0);
+    passQuad->addQuadTextureSource(0, "colorTexture");
+    passQuad->addQuadTextureSource(1, "depthTexture");
     passQuad->mFrustumCorners =
         Ogre::CompositorPassQuadDef::VIEW_SPACE_CORNERS;
   }
 
   Ogre::CompositorWorkspaceDef *workDef =
-      ogreCompMgr->addWorkspaceDefinition(workspaceName);
+      this->dataPtr->ogreCompMgr->addWorkspaceDefinition(
+      this->dataPtr->ogreCompWorkspaceDefName);
   workDef->connectExternal(0, nodeDef->getName(), 0);
 
   this->dataPtr->ogreCompositorWorkspace =
-      ogreCompMgr->addWorkspace(this->dataPtr->scene->OgreSceneManager(),
-      this->dataPtr->renderTexture,
-      this->dataPtr->selectionCamera, workspaceName, false);
-
-  // add the listener
-  Ogre::CompositorNode *node =
-      this->dataPtr->ogreCompositorWorkspace->getNodeSequence()[0];
-  auto channelsTex = node->getLocalTextures();
-
-  for (auto &c : channelsTex)
-  {
-    if (c.textures[0]->getSrcFormat() == Ogre::PF_FLOAT32_RGBA)
-    {
-      c.target->addListener(
-          this->dataPtr->materialSwitcher.get());
-      break;
-    }
-  }
-
-  // buffer to store render texture data. Ensure it's at least 4 channels
-  size_t bufferSize = std::max<size_t>(
-      Ogre::PixelUtil::getMemorySize(width, height, 1, format),
-      4u);
-  this->dataPtr->buffer = new float[width * height * 4u];
-  memset(this->dataPtr->buffer, 0, bufferSize);
-  this->dataPtr->pixelBox = new Ogre::PixelBox(width,
-      height, 1, format, this->dataPtr->buffer);
+      this->dataPtr->ogreCompMgr->addWorkspace(
+        this->dataPtr->scene->OgreSceneManager(),
+        this->dataPtr->renderTexture,
+        this->dataPtr->selectionCamera,
+        this->dataPtr->ogreCompWorkspaceDefName,
+        false);
 }
 
+/////////////////////////////////////////////////
+void Ogre2SelectionBuffer::SetDimensions(
+  unsigned int _width, unsigned int _height)
+{
+  if (this->dataPtr->width == _width && this->dataPtr->height == _height)
+    return;
+
+  this->dataPtr->width = _width;
+  this->dataPtr->height = _height;
+
+  this->DeleteRTTBuffer();
+  this->CreateRTTBuffer();
+}
 /////////////////////////////////////////////////
 Ogre::Item *Ogre2SelectionBuffer::OnSelectionClick(const int _x, const int _y)
 {
@@ -367,22 +412,20 @@ bool Ogre2SelectionBuffer::ExecuteQuery(const int _x, const int _y,
   if (!this->dataPtr->camera)
     return false;
 
-  Ogre::Viewport *vp = this->dataPtr->camera->getLastViewport();
-
-  if (!vp)
+  // check camera has valid projection matrix
+  // There could be nan values if camera was resized
+  Ogre::Matrix4 projectionMatrix =
+      this->dataPtr->camera->getProjectionMatrix();
+  if (projectionMatrix.getTrans().isNaN() ||
+      projectionMatrix.extractQuaternion().isNaN())
     return false;
 
-  Ogre::RenderTarget *rt = vp->getTarget();
+   const unsigned int targetWidth = this->dataPtr->width;
+   const unsigned int targetHeight = this->dataPtr->height;
 
-  if (!rt)
-    return false;
-
-  const unsigned int targetWidth = rt->getWidth();
-  const unsigned int targetHeight = rt->getHeight();
-
-  if (_x < 0 || _y < 0 || _x >= static_cast<int>(targetWidth)
-      || _y >= static_cast<int>(targetHeight))
-    return false;
+   if (_x < 0 || _y < 0 || _x >= static_cast<int>(targetWidth)
+       || _y >= static_cast<int>(targetHeight))
+     return false;
 
   // 1x1 selection buffer, adapted from rviz
   // http://docs.ros.org/indigo/api/rviz/html/c++/selection__manager_8cpp.html
@@ -396,6 +439,7 @@ bool Ogre2SelectionBuffer::ExecuteQuery(const int _x, const int _y,
       static_cast<float>(targetWidth - 1) - 0.5f;
   float y2 = static_cast<float>(_y+height) /
       static_cast<float>(targetHeight - 1) - 0.5f;
+
   Ogre::Matrix4 scaleMatrix = Ogre::Matrix4::IDENTITY;
   Ogre::Matrix4 transMatrix = Ogre::Matrix4::IDENTITY;
   scaleMatrix[0][0] = 1.0 / (x2-x1);
@@ -403,52 +447,31 @@ bool Ogre2SelectionBuffer::ExecuteQuery(const int _x, const int _y,
   transMatrix[0][3] -= x1+x2;
   transMatrix[1][3] += y1+y2;
   Ogre::Matrix4 customProjectionMatrix =
-      scaleMatrix * transMatrix * this->dataPtr->camera->getProjectionMatrix();
-
-  // There is a bug in ogre 2.1 that produces incorrect frustum
-  // extents when a custom projection matrix is set.
-  // So we manually compute the frusm extents ourselves
-  // \todo(anyone) The bug should be fixed in ogre 2.2 so we should be
-  // able to uncomment the setCustomProjectionMatrix call below
-  // and remove the extents set by setFrustumExtents
-  // this->dataPtr->selectionCamera->setCustomProjectionMatrix(true,
-  //      customProjectionMatrix);
-  Ogre::Matrix4 invProj = customProjectionMatrix.inverse();
-  Ogre::Vector4 topLeft(-1.0f, 1.0f, -1.0f, 1.0f);
-  Ogre::Vector4 bottomRight(1.0f, -1.0f, -1.0f, 1.0f);
-  topLeft = invProj * topLeft;
-  bottomRight = invProj * bottomRight;
-  float left = topLeft.x / topLeft.w;
-  float top = topLeft.y / topLeft.w;
-  float right = bottomRight.x / bottomRight.w;
-  float bottom = bottomRight.y / bottomRight.w;
-  this->dataPtr->selectionCamera->setFrustumExtents(left, right, top, bottom);
+      scaleMatrix * transMatrix *
+      this->dataPtr->camera->getProjectionMatrix();
+  this->dataPtr->selectionCamera->setCustomProjectionMatrix(true,
+      customProjectionMatrix);
 
   this->dataPtr->selectionCamera->setPosition(
       this->dataPtr->camera->getDerivedPosition());
   this->dataPtr->selectionCamera->setOrientation(
       this->dataPtr->camera->getDerivedOrientation());
-  Ogre::Viewport* renderViewport =
-      this->dataPtr->renderTexture->getViewport(0);
-  renderViewport->setDimensions(0, 0, width, height);
 
   // update render texture
   this->Update();
 
-  if (!this->dataPtr->buffer)
-  {
-    ignerr << "Selection buffer is null." << std::endl;
-    return false;
-  }
+  Ogre::Image2 image;
+  image.convertFromTexture(this->dataPtr->renderTexture, 0, 0);
+  Ogre::ColourValue pixel = image.getColourAt(0, 0, 0, 0);
 
-  float color = this->dataPtr->buffer[3];
+  float color = pixel[3];
   uint32_t *rgba = reinterpret_cast<uint32_t *>(&color);
   unsigned int r = *rgba >> 24 & 0xFF;
   unsigned int g = *rgba >> 16 & 0xFF;
   unsigned int b = *rgba >> 8 & 0xFF;
 
-  math::Vector3d point(this->dataPtr->buffer[0], this->dataPtr->buffer[1],
-      this->dataPtr->buffer[2]);
+  math::Vector3d point(pixel[0], pixel[1], pixel[2]);
+
   auto rot = Ogre2Conversions::Convert(
       this->dataPtr->camera->getParentSceneNode()->_getDerivedOrientation());
   auto pos = Ogre2Conversions::Convert(
