@@ -23,6 +23,15 @@
   #include <windows.h>
 #endif
 
+#ifdef __APPLE__
+  #define GL_SILENCE_DEPRECATION
+  #include <OpenGL/gl.h>
+#else
+#ifndef _WIN32
+  #include <GL/gl.h>
+#endif
+#endif
+
 #include <math.h>
 
 #include <algorithm>
@@ -57,6 +66,8 @@
 #include "ignition/rendering/ogre2/Ogre2ThermalCamera.hh"
 #include "ignition/rendering/ogre2/Ogre2Visual.hh"
 
+#include <ignition/common/Image.hh>
+
 namespace ignition
 {
 namespace rendering
@@ -65,7 +76,7 @@ inline namespace IGNITION_RENDERING_VERSION_NAMESPACE {
 //
 /// \brief Helper class for switching the ogre item's material to heat source
 /// material when a thermal camera is being rendered.
-class Ogre2ThermalCameraMaterialSwitcher : public Ogre::RenderTargetListener
+class Ogre2ThermalCameraMaterialSwitcher : public Ogre::Camera::Listener
 {
   /// \brief constructor
   /// \param[in] _scene the scene manager responsible for rendering
@@ -84,17 +95,15 @@ class Ogre2ThermalCameraMaterialSwitcher : public Ogre::RenderTargetListener
   /// \param[in] _resolution Temperature linear resolution
   public: void SetLinearResolution(double _resolution);
 
-  /// \brief Callback when a render target is about to be rendered
-  /// \param[in] _evt Ogre render target event containing information about
-  /// the source render target.
-  private: virtual void preRenderTargetUpdate(
-      const Ogre::RenderTargetEvent &_evt) override;
+  /// \brief Callback when a camara is about to be rendered
+  /// \param[in] _cam Ogre camera pointer which is about to render
+  private: virtual void cameraPreRenderScene(
+    Ogre::Camera * _cam) override;
 
-  /// \brief Callback when a render target is finisned being rendered
-  /// \param[in] _evt Ogre render target event containing information about
-  /// the source render target.
-  private: virtual void postRenderTargetUpdate(
-      const Ogre::RenderTargetEvent &_evt) override;
+  /// \brief Callback when a camera is finisned being rendered
+  /// \param[in] _cam Ogre camera pointer which has already render
+  private: virtual void cameraPostRenderScene(
+    Ogre::Camera * _cam) override;
 
   /// \brief Scene manager
   private: Ogre2ScenePtr scene = nullptr;
@@ -129,6 +138,9 @@ class Ogre2ThermalCameraMaterialSwitcher : public Ogre::RenderTargetListener
   private: std::unordered_map<Ogre::SubItem *, Ogre::HlmsDatablock *>
       datablockMap;
 
+  /// \brief A map of ogre sub item pointer to their original low level material
+  private: std::map<Ogre::SubItem *, Ogre::MaterialPtr> thermalMaterialMap;
+
   /// \brief linear temperature resolution. Defaults to 10mK
   private: double resolution = 0.01;
 
@@ -142,14 +154,10 @@ class Ogre2ThermalCameraMaterialSwitcher : public Ogre::RenderTargetListener
 }
 }
 
-
 /// \internal
 /// \brief Private data for the Ogre2ThermalCamera class
 class ignition::rendering::Ogre2ThermalCameraPrivate
 {
-  /// \brief The thermal buffer
-  public: unsigned char *thermalBuffer = nullptr;
-
   /// \brief Outgoing thermal data, used by newThermalFrame event.
   public: uint16_t *thermalImage = nullptr;
 
@@ -169,7 +177,7 @@ class ignition::rendering::Ogre2ThermalCameraPrivate
   public: Ogre::CompositorWorkspace *ogreCompositorWorkspace;
 
   /// \brief Thermal textures.
-  public: Ogre::TexturePtr ogreThermalTexture;
+  public: Ogre::TextureGpu *ogreThermalTexture{nullptr};
 
   /// \brief Dummy render texture for the thermal data
   public: RenderTexturePtr thermalTexture = nullptr;
@@ -230,13 +238,12 @@ void Ogre2ThermalCameraMaterialSwitcher::SetLinearResolution(double _resolution)
   this->resolution = _resolution;
 }
 //////////////////////////////////////////////////
-void Ogre2ThermalCameraMaterialSwitcher::preRenderTargetUpdate(
-    const Ogre::RenderTargetEvent & /*_evt*/)
+void Ogre2ThermalCameraMaterialSwitcher::cameraPreRenderScene(
+    Ogre::Camera * /*_cam*/)
 {
   // swap item to use v1 shader material
   // Note: keep an eye out for performance impact on switching materials
   // on the fly. We are not doing this often so should be ok.
-  this->datablockMap.clear();
   auto itor = this->scene->OgreSceneManager()->getMovableObjectIterator(
       Ogre::ItemFactory::FACTORY_TYPE_NAME);
   while (itor.hasMoreElements())
@@ -281,7 +288,7 @@ void Ogre2ThermalCameraMaterialSwitcher::preRenderTargetUpdate(
           {
             try
             {
-              temp = std::get<int>(tempAny);
+              temp = static_cast<float>(std::get<int>(tempAny));
             }
             catch(std::bad_variant_access &e)
             {
@@ -313,9 +320,18 @@ void Ogre2ThermalCameraMaterialSwitcher::preRenderTargetUpdate(
           // see media/materials/programs/thermal_camera_fs.glsl
           subItem->setCustomParameter(this->customParamIdx,
               Ogre::Vector4(color, 0, 0, 0.0));
-          Ogre::HlmsDatablock *datablock = subItem->getDatablock();
-          this->datablockMap[subItem] = datablock;
-
+          // case when item is using low level materials
+          // e.g. shaders
+          if (!subItem->getMaterial().isNull())
+          {
+            this->thermalMaterialMap[subItem] = subItem->getMaterial();
+          }
+          // regular Pbs Hlms datablock
+          else
+          {
+            Ogre::HlmsDatablock *datablock = subItem->getDatablock();
+            this->datablockMap[subItem] = datablock;
+          }
           subItem->setMaterial(this->heatSourceMaterial);
         }
       }
@@ -378,8 +394,18 @@ void Ogre2ThermalCameraMaterialSwitcher::preRenderTargetUpdate(
         {
           Ogre::SubItem *subItem = item->getSubItem(i);
 
-          Ogre::HlmsDatablock *datablock = subItem->getDatablock();
-          this->datablockMap[subItem] = datablock;
+          // case when item is using low level materials
+          // e.g. shaders
+          if (!subItem->getMaterial().isNull())
+          {
+            this->thermalMaterialMap[subItem] = subItem->getMaterial();
+          }
+          // regular Pbs Hlms datablock
+          else
+          {
+            Ogre::HlmsDatablock *datablock = subItem->getDatablock();
+            this->datablockMap[subItem] = datablock;
+          }
 
           subItem->setMaterial(this->heatSignatureMaterials[item->getId()]);
         }
@@ -408,8 +434,16 @@ void Ogre2ThermalCameraMaterialSwitcher::preRenderTargetUpdate(
             for (unsigned int i = 0; i < item->getNumSubItems(); ++i)
             {
               Ogre::SubItem *subItem = item->getSubItem(i);
-              Ogre::HlmsDatablock *datablock = subItem->getDatablock();
-              this->datablockMap[subItem] = datablock;
+              if (!subItem->getMaterial().isNull())
+              {
+                this->thermalMaterialMap[subItem] = subItem->getMaterial();
+              }
+              // regular Pbs Hlms datablock
+              else
+              {
+                Ogre::HlmsDatablock *datablock = subItem->getDatablock();
+                this->datablockMap[subItem] = datablock;
+              }
               subItem->setDatablock(unlit);
             }
           }
@@ -421,8 +455,8 @@ void Ogre2ThermalCameraMaterialSwitcher::preRenderTargetUpdate(
 }
 
 //////////////////////////////////////////////////
-void Ogre2ThermalCameraMaterialSwitcher::postRenderTargetUpdate(
-    const Ogre::RenderTargetEvent & /*_evt*/)
+void Ogre2ThermalCameraMaterialSwitcher::cameraPostRenderScene(
+    Ogre::Camera * /*_cam*/)
 {
   // restore item to use pbs hlms material
   for (auto it : this->datablockMap)
@@ -430,6 +464,16 @@ void Ogre2ThermalCameraMaterialSwitcher::postRenderTargetUpdate(
     Ogre::SubItem *subItem = it.first;
     subItem->setDatablock(it.second);
   }
+
+  // restore item to use low level material
+  for (auto it : this->thermalMaterialMap)
+  {
+    Ogre::SubItem *subItem = it.first;
+    subItem->setMaterial(it.second);
+  }
+
+  this->datablockMap.clear();
+  this->thermalMaterialMap.clear();
 }
 
 //////////////////////////////////////////////////
@@ -462,12 +506,6 @@ void Ogre2ThermalCamera::Init()
 //////////////////////////////////////////////////
 void Ogre2ThermalCamera::Destroy()
 {
-  if (this->dataPtr->thermalBuffer)
-  {
-    delete [] this->dataPtr->thermalBuffer;
-    this->dataPtr->thermalBuffer = nullptr;
-  }
-
   if (this->dataPtr->thermalImage)
   {
     delete [] this->dataPtr->thermalImage;
@@ -479,13 +517,14 @@ void Ogre2ThermalCamera::Destroy()
 
   auto engine = Ogre2RenderEngine::Instance();
   auto ogreRoot = engine->OgreRoot();
-  Ogre::CompositorManager2 *ogreCompMgr = ogreRoot->getCompositorManager2();
+  auto ogreCompMgr = ogreRoot->getCompositorManager2();
 
   // remove thermal texture, material, compositor
   if (this->dataPtr->ogreThermalTexture)
   {
-    Ogre::TextureManager::getSingleton().remove(
-        this->dataPtr->ogreThermalTexture->getName());
+    ogreRoot->getRenderSystem()->getTextureGpuManager()->destroyTexture(
+      this->dataPtr->ogreThermalTexture);
+    this->dataPtr->ogreThermalTexture = nullptr;
   }
   if (this->dataPtr->ogreCompositorWorkspace)
   {
@@ -497,6 +536,7 @@ void Ogre2ThermalCamera::Destroy()
   {
     Ogre::MaterialManager::getSingleton().remove(
         this->dataPtr->thermalMaterial->getName());
+    this->dataPtr->thermalMaterial.setNull();
   }
 
   if (!this->dataPtr->ogreCompositorWorkspaceDef.empty())
@@ -521,6 +561,8 @@ void Ogre2ThermalCamera::Destroy()
       this->ogreCamera = nullptr;
     }
   }
+
+  this->dataPtr->thermalMaterialSwitcher.reset();
 }
 
 //////////////////////////////////////////////////
@@ -571,8 +613,8 @@ void Ogre2ThermalCamera::CreateRenderTexture()
 void Ogre2ThermalCamera::CreateThermalTexture()
 {
   // set aspect ratio and fov
-  double vfov = 2.0 * atan(tan(this->HFOV().Radian() / 2.0) / this->aspect);
-  this->ogreCamera->setAspectRatio(this->aspect);
+  double vfov;
+  vfov = 2.0 * atan(tan(this->HFOV().Radian() / 2.0) / this->AspectRatio());
   this->ogreCamera->setFOVy(Ogre::Radian(vfov));
 
   // Load thermal material
@@ -597,15 +639,15 @@ void Ogre2ThermalCamera::CreateThermalTexture()
 
   // only support 8 bit and 16 bit formats for now.
   // default to 16 bit
-  Ogre::PixelFormat ogrePF;
+  Ogre::PixelFormatGpu ogrePF;
   if (this->ImageFormat() == PF_L8)
   {
-    ogrePF = Ogre::PF_L8;
+    ogrePF = Ogre::PFG_R8_UNORM;
   }
   else
   {
     this->SetImageFormat(PF_L16);
-    ogrePF = Ogre::PF_L16;
+    ogrePF = Ogre::PFG_R16_UNORM;
   }
 
   PixelFormat format = this->ImageFormat();
@@ -616,10 +658,10 @@ void Ogre2ThermalCamera::CreateThermalTexture()
   // The other params are used to clamp the range output
   // Use the 'real' clip distance here so thermal can be
   // linearized correctly
-  double projectionA = farPlane /
-      (farPlane - nearPlane);
-  double projectionB = (-farPlane * nearPlane) /
-      (farPlane - nearPlane);
+  Ogre::Vector2 projectionAB =
+    this->ogreCamera->getProjectionParamsAB();
+  double projectionA = projectionAB.x;
+  double projectionB = projectionAB.y;
   projectionB /= farPlane;
   psParams->setNamedConstant("projectionParams",
       Ogre::Vector2(projectionA, projectionB));
@@ -656,8 +698,14 @@ void Ogre2ThermalCamera::CreateThermalTexture()
   // compositor_node ThermalCamera
   // {
   //   in 0 rt_input
-  //   texture depthTexture target_width target_height PF_D32_FLOAT
-  //   texture colorTexture target_width target_height PF_R8G8B8A8
+  //   texture depthTexture target_width target_height PFG_D32_FLOAT
+  //   texture colorTexture target_width target_height PFG_RGBA8_UNORM
+  //
+  //   rtv colorTexture
+  //   {
+  //     depth depthTexture
+  //   }
+  //
   //   target colorTexture
   //   {
   //     pass clear
@@ -697,57 +745,51 @@ void Ogre2ThermalCamera::CreateThermalTexture()
         Ogre::TextureDefinitionBase::TEXTURE_INPUT);
     Ogre::TextureDefinitionBase::TextureDefinition *thermalTexDef =
         nodeDef->addTextureDefinition("depthTexture");
-    thermalTexDef->textureType = Ogre::TEX_TYPE_2D;
+    thermalTexDef->textureType = Ogre::TextureTypes::Type2D;
     thermalTexDef->width = 0;
     thermalTexDef->height = 0;
-    thermalTexDef->depth = 1;
+    thermalTexDef->depthOrSlices = 1;
     thermalTexDef->numMipmaps = 0;
     thermalTexDef->widthFactor = 1;
     thermalTexDef->heightFactor = 1;
-    thermalTexDef->formatList = {Ogre::PF_D32_FLOAT};
-    thermalTexDef->fsaa = 0;
-    thermalTexDef->uav = false;
-    thermalTexDef->automipmaps = false;
-    thermalTexDef->hwGammaWrite = Ogre::TextureDefinitionBase::BoolFalse;
+    thermalTexDef->format = Ogre::PFG_D32_FLOAT;
+    thermalTexDef->textureFlags &= ~Ogre::TextureFlags::Uav;
     // set to default pool so that when the colorTexture pass is rendered, its
     // depth data get populated to depthTexture
     thermalTexDef->depthBufferId = Ogre::DepthBuffer::POOL_DEFAULT;
-    thermalTexDef->depthBufferFormat = Ogre::PF_UNKNOWN;
-    thermalTexDef->fsaaExplicitResolve = false;
+    thermalTexDef->depthBufferFormat = Ogre::PFG_UNKNOWN;
 
     Ogre::TextureDefinitionBase::TextureDefinition *colorTexDef =
         nodeDef->addTextureDefinition("colorTexture");
-    colorTexDef->textureType = Ogre::TEX_TYPE_2D;
+    colorTexDef->textureType = Ogre::TextureTypes::Type2D;
     colorTexDef->width = 0;
     colorTexDef->height = 0;
-    colorTexDef->depth = 1;
+    colorTexDef->depthOrSlices = 1;
     colorTexDef->numMipmaps = 0;
     colorTexDef->widthFactor = 1;
     colorTexDef->heightFactor = 1;
-    colorTexDef->formatList = {Ogre::PF_R8G8B8A8};
-    colorTexDef->fsaa = 0;
-    colorTexDef->uav = false;
-    colorTexDef->automipmaps = false;
-    colorTexDef->hwGammaWrite = Ogre::TextureDefinitionBase::BoolFalse;
+    colorTexDef->format = Ogre::PFG_RGBA8_UNORM;
+    colorTexDef->textureFlags &= ~Ogre::TextureFlags::Uav;
     colorTexDef->depthBufferId = Ogre::DepthBuffer::POOL_DEFAULT;
-    colorTexDef->depthBufferFormat = Ogre::PF_D32_FLOAT;
+    colorTexDef->depthBufferFormat = Ogre::PFG_D32_FLOAT;
     colorTexDef->preferDepthTexture = true;
-    colorTexDef->fsaaExplicitResolve = false;
+
+    Ogre::RenderTargetViewDef *rtv =
+      nodeDef->addRenderTextureView("colorTexture");
+    rtv->setForTextureDefinition("colorTexture", colorTexDef);
+    rtv->depthAttachment.textureName = "depthTexture";
 
     nodeDef->setNumTargetPass(2);
     Ogre::CompositorTargetDef *colorTargetDef =
         nodeDef->addTargetPass("colorTexture");
-    colorTargetDef->setNumPasses(2);
+    colorTargetDef->setNumPasses(1);
     {
-      // clear pass
-      Ogre::CompositorPassClearDef *passClear =
-          static_cast<Ogre::CompositorPassClearDef *>(
-          colorTargetDef->addPass(Ogre::PASS_CLEAR));
-      passClear->mColourValue = Ogre::ColourValue(0, 0, 0);
       // scene pass
       Ogre::CompositorPassSceneDef *passScene =
           static_cast<Ogre::CompositorPassSceneDef *>(
           colorTargetDef->addPass(Ogre::PASS_SCENE));
+      passScene->setAllLoadActions(Ogre::LoadAction::Clear);
+      passScene->setAllClearColours(Ogre::ColourValue(0, 0, 0));
       // thermal camera should not see particles
       passScene->mVisibilityMask = IGN_VISIBILITY_ALL &
           ~Ogre2ParticleEmitter::kParticleVisibilityFlags;
@@ -756,20 +798,18 @@ void Ogre2ThermalCamera::CreateThermalTexture()
     // rt_input target - converts to thermal
     Ogre::CompositorTargetDef *inputTargetDef =
         nodeDef->addTargetPass("rt_input");
-    inputTargetDef->setNumPasses(2);
+    inputTargetDef->setNumPasses(1);
     {
-      // clear pass
-      Ogre::CompositorPassClearDef *passClear =
-          static_cast<Ogre::CompositorPassClearDef *>(
-          inputTargetDef->addPass(Ogre::PASS_CLEAR));
-      passClear->mColourValue = Ogre::ColourValue(this->ambient, 0, 1.0);
       // quad pass
       Ogre::CompositorPassQuadDef *passQuad =
           static_cast<Ogre::CompositorPassQuadDef *>(
           inputTargetDef->addPass(Ogre::PASS_QUAD));
+      passQuad->setAllLoadActions(Ogre::LoadAction::Clear);
+      passQuad->setAllClearColours(Ogre::ColourValue(this->ambient, 0, 1.0));
+
       passQuad->mMaterialName = this->dataPtr->thermalMaterial->getName();
-      passQuad->addQuadTextureSource(0, "depthTexture", 0);
-      passQuad->addQuadTextureSource(1, "colorTexture", 0);
+      passQuad->addQuadTextureSource(0, "depthTexture");
+      passQuad->addQuadTextureSource(1, "colorTexture");
       passQuad->mFrustumCorners =
           Ogre::CompositorPassQuadDef::VIEW_SPACE_CORNERS;
     }
@@ -787,37 +827,49 @@ void Ogre2ThermalCamera::CreateThermalTexture()
            << " for " << this->Name();
   }
 
+  Ogre::TextureGpuManager *textureMgr =
+    ogreRoot->getRenderSystem()->getTextureGpuManager();
   // create render texture - these textures pack the thermal data
   this->dataPtr->ogreThermalTexture =
-    Ogre::TextureManager::getSingleton().createManual(
-    this->Name() + "_thermal", "General", Ogre::TEX_TYPE_2D,
-    this->ImageWidth(), this->ImageHeight(), 1, 0,
-    ogrePF, Ogre::TU_RENDERTARGET,
-    0, false, 0, Ogre::BLANKSTRING, false, true);
+    textureMgr->createOrRetrieveTexture(this->Name() + "_thermal",
+      Ogre::GpuPageOutStrategy::SaveToSystemRam,
+      Ogre::TextureFlags::RenderToTexture,
+      Ogre::TextureTypes::Type2D);
 
-  Ogre::RenderTarget *rt =
-    this->dataPtr->ogreThermalTexture->getBuffer()->getRenderTarget();
+  this->dataPtr->ogreThermalTexture->setResolution(
+    this->ImageWidth(), this->ImageHeight());
+  this->dataPtr->ogreThermalTexture->setNumMipmaps(1u);
+  this->dataPtr->ogreThermalTexture->setPixelFormat(
+    ogrePF);
+
+  this->dataPtr->ogreThermalTexture->scheduleTransitionTo(
+    Ogre::GpuResidency::Resident);
 
   // create compositor worksspace
   this->dataPtr->ogreCompositorWorkspace =
-      ogreCompMgr->addWorkspace(this->scene->OgreSceneManager(),
-      rt, this->ogreCamera, wsDefName, false);
+      ogreCompMgr->addWorkspace(
+        this->scene->OgreSceneManager(),
+        this->dataPtr->ogreThermalTexture,
+        this->ogreCamera,
+        wsDefName,
+        false);
 
-  // add thermal material swticher to render target listener
+  // add thermal material switcher to render target listener
   // so we can switch to use heat material when the camera is being udpated
   Ogre::CompositorNode *node =
       this->dataPtr->ogreCompositorWorkspace->getNodeSequence()[0];
   auto channels = node->getLocalTextures();
   for (auto c : channels)
   {
-    if (c.textures[0]->getSrcFormat() == Ogre::PF_R8G8B8A8)
+    if (c->getPixelFormat() == Ogre::PFG_RGBA8_UNORM)
     {
       this->dataPtr->thermalMaterialSwitcher.reset(
           new Ogre2ThermalCameraMaterialSwitcher(this->scene, this->Name()));
       this->dataPtr->thermalMaterialSwitcher->SetFormat(this->ImageFormat());
       this->dataPtr->thermalMaterialSwitcher->SetLinearResolution(
           this->resolution);
-      c.target->addListener(this->dataPtr->thermalMaterialSwitcher.get());
+      this->ogreCamera->addListener(
+        this->dataPtr->thermalMaterialSwitcher.get());
       break;
     }
   }
@@ -826,11 +878,35 @@ void Ogre2ThermalCamera::CreateThermalTexture()
 //////////////////////////////////////////////////
 void Ogre2ThermalCamera::Render()
 {
-  // update the compositors
-  this->dataPtr->ogreCompositorWorkspace->setEnabled(true);
+  // GL_DEPTH_CLAMP is disabled in later version of ogre2.2
+  // however our shaders rely on clamped values so enable it for this sensor
   auto engine = Ogre2RenderEngine::Instance();
-  engine->OgreRoot()->renderOneFrame();
-  this->dataPtr->ogreCompositorWorkspace->setEnabled(false);
+  std::string renderSystemName =
+      engine->OgreRoot()->getRenderSystem()->getFriendlyName();
+  bool useGL = renderSystemName.find("OpenGL") != std::string::npos;
+#ifndef _WIN32
+  if (useGL)
+    glEnable(GL_DEPTH_CLAMP);
+#endif
+
+  // update the compositors
+  this->scene->StartRendering(this->ogreCamera);
+
+  this->dataPtr->ogreCompositorWorkspace->_validateFinalTarget();
+  this->dataPtr->ogreCompositorWorkspace->_beginUpdate(false);
+  this->dataPtr->ogreCompositorWorkspace->_update();
+  this->dataPtr->ogreCompositorWorkspace->_endUpdate(false);
+
+  Ogre::vector<Ogre::TextureGpu*>::type swappedTargets;
+  swappedTargets.reserve(2u);
+  this->dataPtr->ogreCompositorWorkspace->_swapFinalTarget(swappedTargets);
+
+  this->scene->FlushGpuCommandsAndStartNewFrame(1u, false);
+
+#ifndef _WIN32
+  if (useGL)
+    glDisable(GL_DEPTH_CLAMP);
+#endif
 }
 
 //////////////////////////////////////////////////
@@ -849,50 +925,49 @@ void Ogre2ThermalCamera::PostRender()
   unsigned int width = this->ImageWidth();
   unsigned int height = this->ImageHeight();
   PixelFormat format = this->ImageFormat();
-  Ogre::PixelFormat imageFormat = Ogre2Conversions::Convert(format);
 
   int len = width * height;
   unsigned int channelCount = PixelUtil::ChannelCount(format);
   unsigned int bytesPerChannel = PixelUtil::BytesPerChannel(format);
 
-  if (!this->dataPtr->thermalBuffer)
-  {
-    this->dataPtr->thermalBuffer =
-        new unsigned char[len * channelCount * bytesPerChannel];
-  }
-  Ogre::PixelBox dstBox(width, height,
-        1, imageFormat, this->dataPtr->thermalBuffer);
-
-  // blit data from gpu to cpu
-  auto rt = this->dataPtr->ogreThermalTexture->getBuffer()->getRenderTarget();
-  rt->copyContentsToMemory(dstBox, Ogre::RenderTarget::FB_FRONT);
+  Ogre::Image2 image;
+  image.convertFromTexture(this->dataPtr->ogreThermalTexture, 0u, 0u);
 
   if (!this->dataPtr->thermalImage)
   {
     this->dataPtr->thermalImage = new uint16_t[len];
   }
 
+  Ogre::TextureBox box = image.getData(0u);
   if (format == PF_L8)
   {
-    // workaround for populating a 16bit image buffer with 8bit data
-    // \todo(anyone) add a new ConnectNewThermalFrame function that accepts
-    // a generic unsigned char array instead of uint16_t so we can do a direct
-    // memcpy of the data
+    uint8_t *thermalBuffer = static_cast<uint8_t*>(box.data);
     for (unsigned int i = 0u; i < height; ++i)
     {
+      // the texture box step size could be larger than our image buffer step
+      // size
+      unsigned int rawDataRowIdx = i * box.bytesPerRow / bytesPerChannel;
       for (unsigned int j = 0u; j < width; ++j)
       {
         unsigned int idx = (i * width) + j;
-        this->dataPtr->thermalImage[idx] = static_cast<uint16_t>(
-            this->dataPtr->thermalBuffer[idx]);
+        this->dataPtr->thermalImage[idx] = thermalBuffer[rawDataRowIdx + j];
       }
     }
   }
   else
   {
     // fill thermal data
-    memcpy(this->dataPtr->thermalImage, this->dataPtr->thermalBuffer,
-        height * width * channelCount * bytesPerChannel);
+    // copy data row by row. The texture box may not be a contiguous region of
+    // a texture
+    uint16_t * thermalBuffer = static_cast<uint16_t *>(box.data);
+    for (unsigned int i = 0; i < height; ++i)
+    {
+      unsigned int rawDataRowIdx = i * box.bytesPerRow / bytesPerChannel;
+      unsigned int rowIdx = i * width * channelCount;
+      memcpy(&this->dataPtr->thermalImage[rowIdx],
+          &thermalBuffer[rawDataRowIdx],
+          width * channelCount * bytesPerChannel);
+    }
   }
 
   this->dataPtr->newThermalFrame(
