@@ -17,18 +17,17 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
-#include "gz/rendering/Camera.hh"
-#include "gz/rendering/GaussianNoisePass.hh"
-#include "gz/rendering/RenderEngine.hh"
-#include "gz/rendering/RenderingIface.hh"
-#include "gz/rendering/RenderPassSystem.hh"
-#include "gz/rendering/Scene.hh"
-#include "gz/rendering/Utils.hh"
+#include "ignition/rendering/Camera.hh"
+#include "ignition/rendering/GaussianNoisePass.hh"
+#include "ignition/rendering/RenderEngine.hh"
+#include "ignition/rendering/RenderingIface.hh"
+#include "ignition/rendering/RenderPassSystem.hh"
+#include "ignition/rendering/Scene.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 class CameraTest : public testing::Test,
@@ -48,23 +47,16 @@ class CameraTest : public testing::Test,
 
   /// \brief Test setting visibility mask
   public: void VisibilityMask(const std::string &_renderEngine);
-
-  /// \brief Test setting intrinsic matrix
-  public: void IntrinsicMatrix(const std::string &_renderEngine);
 };
 
 /////////////////////////////////////////////////
 void CameraTest::ViewProjectionMatrix(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   // create and populate scene
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -157,21 +149,17 @@ void CameraTest::ViewProjectionMatrix(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void CameraTest::RenderTexture(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   // create and populate scene
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -215,21 +203,17 @@ void CameraTest::RenderTexture(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void CameraTest::TrackFollow(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   // create and populate scene
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -291,21 +275,17 @@ void CameraTest::TrackFollow(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void CameraTest::AddRemoveRenderPass(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   // create and populate scene
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -349,21 +329,17 @@ void CameraTest::AddRemoveRenderPass(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void CameraTest::VisibilityMask(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   // create and populate scene
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -389,86 +365,6 @@ void CameraTest::VisibilityMask(const std::string &_renderEngine)
   rendering::unloadEngine(engine->Name());
 }
 
-/////////////////////////////////////////////////
-void CameraTest::IntrinsicMatrix(const std::string &_renderEngine)
-{
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
-  // create and populate scene
-  RenderEngine *engine = rendering::engine(_renderEngine);
-  if (!engine)
-  {
-    FAIL() << "Engine '" << _renderEngine
-              << "' is not supported" << std::endl;
-    return;
-  }
-
-  ScenePtr scene = engine->CreateScene("scene");
-  ASSERT_NE(nullptr, scene);
-
-  CameraPtr camera = scene->CreateCamera();
-  EXPECT_TRUE(camera != nullptr);
-
-  unsigned int width = 320;
-  unsigned int height = 240;
-  double hfov = 1.047;
-
-  camera->SetImageHeight(height);
-  camera->SetImageWidth(width);
-  camera->SetHFOV(hfov);
-
-  double error = 1e-1;
-  EXPECT_EQ(camera->ImageHeight(), height);
-  EXPECT_EQ(camera->ImageWidth(), width);
-  EXPECT_NEAR(camera->HFOV().Radian(), hfov, error);
-
-  // Verify focal length and optical center from intrinsics
-  auto cameraIntrinsics = projectionToCameraIntrinsic(
-      camera->ProjectionMatrix(),
-      camera->ImageWidth(),
-      camera->ImageHeight()
-    );
-  EXPECT_NEAR(cameraIntrinsics(0, 0), 277.1913, error);
-  EXPECT_NEAR(cameraIntrinsics(1, 1), 277.1913, error);
-  EXPECT_DOUBLE_EQ(cameraIntrinsics(0, 2), 160);
-  EXPECT_DOUBLE_EQ(cameraIntrinsics(1, 2), 120);
-
-  // Verify rest of the intrinsics
-  EXPECT_DOUBLE_EQ(cameraIntrinsics(0, 1), 0);
-  EXPECT_DOUBLE_EQ(cameraIntrinsics(1, 0), 0);
-  EXPECT_DOUBLE_EQ(cameraIntrinsics(0, 1), 0);
-  EXPECT_DOUBLE_EQ(cameraIntrinsics(2, 0), 0);
-  EXPECT_DOUBLE_EQ(cameraIntrinsics(2, 1), 0);
-  EXPECT_DOUBLE_EQ(cameraIntrinsics(2, 2), 1);
-
-  // Verify that changing camera size changes intrinsics
-  height = 1000;
-  width = 1000;
-  camera->SetImageHeight(height);
-  camera->SetImageWidth(width);
-  camera->SetHFOV(hfov);
-
-  EXPECT_EQ(camera->ImageHeight(), height);
-  EXPECT_EQ(camera->ImageWidth(), width);
-  EXPECT_NEAR(camera->HFOV().Radian(), hfov, error);
-
-  // Verify if intrinsics have changed
-  cameraIntrinsics = projectionToCameraIntrinsic(
-      camera->ProjectionMatrix(),
-      camera->ImageWidth(),
-      camera->ImageHeight()
-    );
-  EXPECT_NEAR(cameraIntrinsics(0, 0), 866.223, error);
-  EXPECT_NEAR(cameraIntrinsics(1, 1), 866.223, error);
-  EXPECT_DOUBLE_EQ(cameraIntrinsics(0, 2), 500);
-  EXPECT_DOUBLE_EQ(cameraIntrinsics(1, 2), 500);
-
-  // Clean up
-  engine->DestroyScene(scene);
-}
-
 /////////////////////////////////////////////////
 TEST_P(CameraTest, ViewProjectionMatrix)
 {
@@ -499,15 +395,9 @@ TEST_P(CameraTest, VisibilityMask)
   VisibilityMask(GetParam());
 }
 
-/////////////////////////////////////////////////
-TEST_P(CameraTest, IntrinsicMatrix)
-{
-  IntrinsicMatrix(GetParam());
-}
-
 INSTANTIATE_TEST_CASE_P(Camera, CameraTest,
     RENDER_ENGINE_VALUES,
-    PrintToStringParam());
+    ignition::rendering::PrintToStringParam());
 
 int main(int argc, char **argv)
 {
