@@ -16,16 +16,16 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
-#include "gz/rendering/Marker.hh"
-#include "gz/rendering/Material.hh"
-#include "gz/rendering/RenderEngine.hh"
-#include "gz/rendering/RenderingIface.hh"
-#include "gz/rendering/Scene.hh"
+#include "ignition/rendering/Marker.hh"
+#include "ignition/rendering/Material.hh"
+#include "ignition/rendering/RenderEngine.hh"
+#include "ignition/rendering/RenderingIface.hh"
+#include "ignition/rendering/Scene.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 using namespace std::chrono_literals;
 
@@ -41,10 +41,6 @@ class MarkerTest : public testing::Test,
 /////////////////////////////////////////////////
 void MarkerTest::Marker(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   if (_renderEngine == "optix")
   {
     igndbg << "Marker not supported yet in rendering engine: "
@@ -56,7 +52,7 @@ void MarkerTest::Marker(const std::string &_renderEngine)
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
            << "' is not supported" << std::endl;
     return;
   }
@@ -135,8 +131,6 @@ void MarkerTest::Marker(const std::string &_renderEngine)
   // exercise point api
   EXPECT_NO_THROW(marker->AddPoint(math::Vector3d(0, 1, 2),
       math::Color::White));
-  EXPECT_NO_THROW(marker->AddPoint(-2, -1, 0, math::Color::White));
-
   EXPECT_NO_THROW(marker->SetPoint(0, math::Vector3d(3, 1, 2)));
   EXPECT_NO_THROW(marker->ClearPoints());
 
@@ -144,47 +138,9 @@ void MarkerTest::Marker(const std::string &_renderEngine)
   marker->SetSize(3.0);
   EXPECT_DOUBLE_EQ(3.0, marker->Size());
 
-  marker->PreRender();
-
-  // create material
-  MaterialPtr mat = scene->CreateMaterial();
-  mat->SetAmbient(0.6, 0.7, 0.8);
-  mat->SetDiffuse(0.3, 0.8, 0.2);
-  mat->SetSpecular(0.4, 0.9, 1.0);
-
-  MaterialPtr markerMat;
-  marker->SetType(MarkerType::MT_NONE);
-  marker->SetMaterial(mat);
-  markerMat = marker->Material();
-  ASSERT_NE(nullptr, markerMat);
-
-  marker->SetType(static_cast<MarkerType>(11));
-  marker->SetMaterial(mat);
-  markerMat = marker->Material();
-  ASSERT_NE(nullptr, markerMat);
-
-  marker->SetType(MarkerType::MT_BOX);
-  marker->SetMaterial(mat);
-  markerMat = marker->Material();
-  ASSERT_NE(nullptr, markerMat);
-
-  marker->SetType(MarkerType::MT_POINTS);
-  marker->SetMaterial(mat);
-  markerMat = marker->Material();
-  ASSERT_NE(nullptr, markerMat);
-
-  EXPECT_EQ(math::Color(0.6f, 0.7f, 0.8f), markerMat->Ambient());
-  EXPECT_EQ(math::Color(0.3f, 0.8f, 0.2f), markerMat->Diffuse());
-  EXPECT_EQ(math::Color(0.4f, 0.9f, 1.0f), markerMat->Specular());
-
-
-  MaterialPtr matNull;
-  marker->SetMaterial(matNull, false);
-  ASSERT_NE(nullptr, markerMat);
-
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -200,7 +156,7 @@ void MarkerTest::Material(const std::string &_renderEngine)
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
            << "' is not supported" << std::endl;
     return;
   }
@@ -248,7 +204,7 @@ TEST_P(MarkerTest, Material)
 
 INSTANTIATE_TEST_CASE_P(Marker, MarkerTest,
     RENDER_ENGINE_VALUES,
-    PrintToStringParam());
+    ignition::rendering::PrintToStringParam());
 
 int main(int argc, char **argv)
 {
