@@ -15,22 +15,32 @@
  *
  */
 
-#include <gz/common/Console.hh>
+#include <cmath>
 
-#include "gz/rendering/OrbitViewController.hh"
-#include "gz/rendering/Scene.hh"
-#include "gz/rendering/Visual.hh"
+#include <ignition/common/Console.hh>
 
-class gz::rendering::OrbitViewControllerPrivate
+#include "ignition/rendering/OrbitViewController.hh"
+#include "ignition/rendering/Scene.hh"
+#include "ignition/rendering/Visual.hh"
+
+class ignition::rendering::OrbitViewControllerPrivate
 {
   /// \brief Pointer to camera
   public: CameraPtr camera;
 
   /// \brief Target point for camera movements
   public: math::Vector3d target;
+
+  /// \brief Keep yaw within limits
+  /// \return Normalized yaw
+  public: double NormalizeYaw(double _yaw);
+
+  /// \brief Keep pitch within limits
+  /// \return Normalized pitch
+  public: double NormalizePitch(double _pitch);
 };
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 static const float PITCH_LIMIT_LOW = -static_cast<float>(IGN_PI)*0.5f + 0.001f;
@@ -58,6 +68,9 @@ OrbitViewController::~OrbitViewController()
 void OrbitViewController::SetCamera(const CameraPtr &_camera)
 {
   this->dataPtr->camera = _camera;
+  if (!this->dataPtr->camera)
+    return;
+  this->dataPtr->camera->SetProjectionType(CPT_PERSPECTIVE);
 }
 
 //////////////////////////////////////////////////
@@ -73,7 +86,7 @@ void OrbitViewController::SetTarget(const math::Vector3d &_target)
 }
 
 //////////////////////////////////////////////////
-math::Vector3d OrbitViewController::Target() const
+const math::Vector3d &OrbitViewController::Target() const
 {
   return this->dataPtr->target;
 }
@@ -81,6 +94,13 @@ math::Vector3d OrbitViewController::Target() const
 //////////////////////////////////////////////////
 void OrbitViewController::Zoom(const double _value)
 {
+  if (!std::isfinite(_value))
+  {
+    ignerr << "Failed to zoom by non-finite value [" << _value << "]"
+           << std::endl;
+    return;
+  }
+
   if (!this->dataPtr->camera)
   {
     ignerr << "Camera is NULL" << std::endl;
@@ -102,12 +122,26 @@ void OrbitViewController::Zoom(const double _value)
 //////////////////////////////////////////////////
 void OrbitViewController::Pan(const math::Vector2d &_value)
 {
+  if (!_value.IsFinite())
+  {
+    ignerr << "Failed to pan by non-finite value [" << _value << "]"
+           << std::endl;
+    return;
+  }
+
   if (!this->dataPtr->camera)
   {
     ignerr << "Camera is NULL" << std::endl;
     return;
   }
 
+  if (!this->dataPtr->camera->WorldPosition().IsFinite())
+  {
+    ignerr << "Camera world position isn't finite ["
+           << this->dataPtr->camera->WorldPosition() << "]" << std::endl;
+    return;
+  }
+
   double viewportWidth = this->dataPtr->camera->ImageWidth();
   double viewportHeight = this->dataPtr->camera->ImageHeight();
 
@@ -117,7 +151,7 @@ void OrbitViewController::Pan(const math::Vector2d &_value)
   double vfov = 2.0f * atan(tan(hfov / 2.0f) /
         this->dataPtr->camera->AspectRatio());
 
-  math::Vector3d translation;
+  ignition::math::Vector3d translation;
 
   double factor = 2.0;
 
@@ -137,6 +171,13 @@ void OrbitViewController::Pan(const math::Vector2d &_value)
 //////////////////////////////////////////////////
 void OrbitViewController::Orbit(const math::Vector2d &_value)
 {
+  if (!_value.IsFinite())
+  {
+    ignerr << "Failed to orbit by non-finite value [" << _value << "]"
+           << std::endl;
+    return;
+  }
+
   if (!this->dataPtr->camera)
   {
     ignerr << "Camera is NULL" << std::endl;
@@ -170,3 +211,26 @@ void OrbitViewController::Orbit(const math::Vector2d &_value)
   this->dataPtr->camera->SetWorldPosition(
       this->dataPtr->camera->WorldPosition() + this->dataPtr->target);
 }
+
+//////////////////////////////////////////////////
+double OrbitViewControllerPrivate::NormalizeYaw(double _yaw)
+{
+  _yaw = fmod(_yaw, IGN_PI*2);
+  if (_yaw < 0.0f)
+  {
+    _yaw = IGN_PI * 2 + _yaw;
+  }
+
+  return _yaw;
+}
+
+//////////////////////////////////////////////////
+double OrbitViewControllerPrivate::NormalizePitch(double _pitch)
+{
+  if (_pitch < PITCH_LIMIT_LOW)
+    _pitch = PITCH_LIMIT_LOW;
+  else if (_pitch > PITCH_LIMIT_HIGH)
+    _pitch = PITCH_LIMIT_HIGH;
+
+  return _pitch;
+}
