@@ -17,16 +17,16 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
-#include "gz/rendering/DistortionPass.hh"
-#include "gz/rendering/GaussianNoisePass.hh"
-#include "gz/rendering/RenderEngine.hh"
-#include "gz/rendering/RenderingIface.hh"
-#include "gz/rendering/RenderPassSystem.hh"
+#include "ignition/rendering/DistortionPass.hh"
+#include "ignition/rendering/GaussianNoisePass.hh"
+#include "ignition/rendering/RenderEngine.hh"
+#include "ignition/rendering/RenderingIface.hh"
+#include "ignition/rendering/RenderPassSystem.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 class RenderPassSystemTest : public testing::Test,
@@ -43,7 +43,7 @@ void RenderPassSystemTest::RenderPassSystem(const std::string &_renderEngine)
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -91,7 +91,7 @@ TEST_P(RenderPassSystemTest, RenderPassSystem)
 
 INSTANTIATE_TEST_CASE_P(GaussianNoise, RenderPassSystemTest,
     RENDER_ENGINE_VALUES,
-    PrintToStringParam());
+    ignition::rendering::PrintToStringParam());
 
 int main(int argc, char **argv)
 {
