@@ -17,15 +17,15 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
-#include "gz/rendering/RenderEngine.hh"
-#include "gz/rendering/RenderTarget.hh"
-#include "gz/rendering/RenderingIface.hh"
-#include "gz/rendering/Scene.hh"
+#include "ignition/rendering/RenderEngine.hh"
+#include "ignition/rendering/RenderTarget.hh"
+#include "ignition/rendering/RenderingIface.hh"
+#include "ignition/rendering/Scene.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 class SceneTest : public testing::Test,
@@ -52,10 +52,6 @@ class SceneTest : public testing::Test,
   /// \brief Test creating and destroying materials
   public: void Materials(const std::string &_renderEngine);
 
-  public: const std::string TEST_MEDIA_PATH =
-        common::joinPaths(std::string(PROJECT_SOURCE_PATH),
-        "test", "media", "skeleton");
-
   /// \brief Test setting and getting Time
   public: void Time(const std::string &_renderEngine);
 
@@ -69,15 +65,11 @@ class SceneTest : public testing::Test,
 /////////////////////////////////////////////////
 void SceneTest::Scene(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   // create and populate scene
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
            << "' is not supported" << std::endl;
     return;
   }
@@ -95,7 +87,7 @@ void SceneTest::Scene(const std::string &_renderEngine)
 
   // TODO(anyone) gradient background color and render window only supported
   // by ogre
-  if (_renderEngine == "ogre2")
+  if (_renderEngine == "ogre")
   {
     EXPECT_FALSE(scene->IsGradientBackgroundColor());
 
@@ -133,20 +125,16 @@ void SceneTest::Scene(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void SceneTest::Nodes(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   auto engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine << "' is not supported" << std::endl;
+    igndbg << "Engine '" << _renderEngine << "' is not supported" << std::endl;
     return;
   }
 
@@ -221,20 +209,16 @@ void SceneTest::Nodes(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void SceneTest::RemoveNodes(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   auto engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine << "' is not supported" << std::endl;
+    igndbg << "Engine '" << _renderEngine << "' is not supported" << std::endl;
     return;
   }
 
@@ -327,20 +311,16 @@ void SceneTest::RemoveNodes(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void SceneTest::DestroyNodes(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   auto engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine << "' is not supported" << std::endl;
+    igndbg << "Engine '" << _renderEngine << "' is not supported" << std::endl;
     return;
   }
 
@@ -476,98 +456,20 @@ void SceneTest::DestroyNodes(const std::string &_renderEngine)
   EXPECT_FALSE(scene->HasVisual(childB));
   EXPECT_FALSE(scene->HasVisual(childAA));
 
-  auto gizmoVisual = scene->CreateGizmoVisual("gizmo_visual");
-  auto planeVisual = scene->CreatePlane();
-  auto meshVisual = scene->CreateMesh(
-    common::joinPaths(TEST_MEDIA_PATH, "walk.dae"));
-
-  common::MeshPtr mesh(new common::Mesh());
-  meshVisual = scene->CreateMesh(mesh.get());
-
-  scene->DestroyVisuals();
-
-  common::Material mat(math::Color(1.0f, 0.5f, 0.2f, 1.0f));
-  auto materialVisual = scene->CreateMaterial(mat);
-  scene->DestroyMaterial(materialVisual);
-  scene->DestroyMaterial(MaterialPtr());
-
-  auto depthCameraSensor = scene->CreateDepthCamera();
-  scene->DestroySensors();
-  depthCameraSensor = scene->CreateDepthCamera("camera_depth");
-  scene->DestroySensorByName("camera_depth");
-  depthCameraSensor = scene->CreateDepthCamera("camera_depth");
-  EXPECT_FALSE(scene->HasSensor(ConstSensorPtr()));
-  EXPECT_FALSE(scene->HasSensorId(8));
-  EXPECT_FALSE(scene->HasSensorName("invalid"));
-  EXPECT_TRUE(scene->HasSensorName("camera_depth"));
-
-  auto dCSensor = scene->SensorByName("camera_depth");
-  EXPECT_TRUE(scene->HasSensor(dCSensor));
-  EXPECT_TRUE(scene->HasSensorName("camera_depth"));
-  scene->DestroySensor(dCSensor, false);
-
-  depthCameraSensor = scene->CreateDepthCamera(76);
-  dCSensor = scene->SensorById(76);
-  EXPECT_TRUE(scene->HasSensor(dCSensor));
-  EXPECT_TRUE(scene->HasSensorId(76));
-  scene->DestroySensor(dCSensor, true);
-
-  depthCameraSensor = scene->CreateDepthCamera(76);
-  scene->DestroySensorById(76);
-
-  depthCameraSensor = scene->CreateDepthCamera();
-  scene->DestroySensorByIndex(0);
-
-  // lights
-  auto spotLight = scene->CreateSpotLight();
-  auto pointLight = scene->CreatePointLight("point_light");
-  auto directionalLight = scene->CreateDirectionalLight(99);
-
-  auto directionalLight2 = scene->LightById(99);
-  EXPECT_EQ(directionalLight, directionalLight2);
-
-  auto directionalLight3 = scene->CreateDirectionalLight("directional_light");
-
-  auto pointLight2 = scene->LightByName("point_light");
-  EXPECT_EQ(pointLight, pointLight2);
-
-  scene->DestroyLightByIndex(0);
-  scene->DestroyLight(pointLight, true);
-  scene->DestroyLights();
-
-  spotLight = scene->CreateSpotLight();
-  scene->DestroyNodeByIndex(0);
-
-  spotLight = scene->CreateSpotLight("light_node");
-  scene->DestroyNodeByName("light_node");
-
-  spotLight = scene->CreateSpotLight(56);
-  scene->DestroyNodeById(56);
-
   EXPECT_EQ(0u, scene->VisualCount());
-  EXPECT_EQ(0u, scene->SensorCount());
-  EXPECT_EQ(0u, scene->LightCount());
-
-  EXPECT_EQ(std::chrono::milliseconds(0), scene->Time());
-  scene->SetTime(std::chrono::milliseconds(3550));
-  EXPECT_EQ(std::chrono::milliseconds(3550), scene->Time());
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void SceneTest::NodeCycle(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   auto engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine << "' is not supported" << std::endl;
+    igndbg << "Engine '" << _renderEngine << "' is not supported" << std::endl;
     return;
   }
 
@@ -624,20 +526,16 @@ void SceneTest::NodeCycle(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void SceneTest::Materials(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   auto engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine << "' is not supported" << std::endl;
+    igndbg << "Engine '" << _renderEngine << "' is not supported" << std::endl;
     return;
   }
 
@@ -758,20 +656,16 @@ void SceneTest::Materials(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void SceneTest::Time(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                                                                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;
-  return;
-#endif
   auto engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine << "' is not supported" << std::endl;
+    igndbg << "Engine '" << _renderEngine << "' is not supported" << std::endl;
     return;
   }
 
@@ -815,14 +709,10 @@ void SceneTest::Time(const std::string &_renderEngine)
 /////////////////////////////////////////////////
 void SceneTest::BackgroundMaterial(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                                                                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;
-  return;
-#endif
   auto engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine << "' is not supported" << std::endl;
+    igndbg << "Engine '" << _renderEngine << "' is not supported" << std::endl;
     return;
   }
 
@@ -846,14 +736,10 @@ void SceneTest::BackgroundMaterial(const std::string &_renderEngine)
 /////////////////////////////////////////////////
 void SceneTest::Sky(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                                                                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;
-  return;
-#endif
   auto engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine << "' is not supported" << std::endl;
+    igndbg << "Engine '" << _renderEngine << "' is not supported" << std::endl;
     return;
   }
 
@@ -951,7 +837,7 @@ TEST_P(SceneTest, Sky)
 
 INSTANTIATE_TEST_CASE_P(Scene, SceneTest,
     RENDER_ENGINE_VALUES,
-    PrintToStringParam());
+    ignition::rendering::PrintToStringParam());
 
 int main(int argc, char **argv)
 {
