@@ -17,17 +17,17 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/common/Console.hh>
+#include <ignition/common/Console.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
 
-#include "gz/rendering/Camera.hh"
-#include "gz/rendering/RenderEngine.hh"
-#include "gz/rendering/RenderingIface.hh"
-#include "gz/rendering/Scene.hh"
-#include "gz/rendering/TransformController.hh"
+#include "ignition/rendering/Camera.hh"
+#include "ignition/rendering/RenderEngine.hh"
+#include "ignition/rendering/RenderingIface.hh"
+#include "ignition/rendering/Scene.hh"
+#include "ignition/rendering/TransformController.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 class TransformControllerTest : public testing::Test,
@@ -49,14 +49,10 @@ class TransformControllerTest : public testing::Test,
 /////////////////////////////////////////////////
 void TransformControllerTest::TransformControl(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -134,20 +130,16 @@ void TransformControllerTest::TransformControl(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void TransformControllerTest::WorldSpace(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -201,20 +193,16 @@ void TransformControllerTest::WorldSpace(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void TransformControllerTest::LocalSpace(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -319,20 +307,16 @@ void TransformControllerTest::LocalSpace(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
 void TransformControllerTest::Control2d(const std::string &_renderEngine)
 {
-#ifdef __APPLE__                                                                              
-  std::cerr << "Skipping test for apple, see issue #847." << std::endl;                       
-  return;
-#endif
   RenderEngine *engine = rendering::engine(_renderEngine);
   if (!engine)
   {
-    FAIL() << "Engine '" << _renderEngine
+    igndbg << "Engine '" << _renderEngine
               << "' is not supported" << std::endl;
     return;
   }
@@ -435,7 +419,7 @@ void TransformControllerTest::Control2d(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 /////////////////////////////////////////////////
 TEST_P(TransformControllerTest, TransformControl)
@@ -463,7 +447,7 @@ TEST_P(TransformControllerTest, Control2d)
 
 INSTANTIATE_TEST_CASE_P(TransformController, TransformControllerTest,
     RENDER_ENGINE_VALUES,
-    PrintToStringParam());
+    ignition::rendering::PrintToStringParam());
 
 int main(int argc, char **argv)
 {
