@@ -17,18 +17,17 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/common/Event.hh>
-#include <gz/utils/ExtraTestMacros.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/common/Event.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
 
-#include "gz/rendering/DepthCamera.hh"
-#include "gz/rendering/ParticleEmitter.hh"
-#include "gz/rendering/RenderEngine.hh"
-#include "gz/rendering/RenderingIface.hh"
-#include "gz/rendering/Scene.hh"
+#include "ignition/rendering/DepthCamera.hh"
+#include "ignition/rendering/ParticleEmitter.hh"
+#include "ignition/rendering/RenderEngine.hh"
+#include "ignition/rendering/RenderingIface.hh"
+#include "ignition/rendering/Scene.hh"
 
 #define DEPTH_TOL 1e-4
 #define DOUBLE_TOL 1e-6
@@ -77,7 +76,7 @@ void DepthCameraTest::DepthCameraBoxes(
   double aspectRatio_ = imgWidth_/imgHeight_;
 
   double unitBoxSize = 1.0;
-  gz::math::Vector3d boxPosition(1.8, 0.0, 0.0);
+  ignition::math::Vector3d boxPosition(1.8, 0.0, 0.0);
 
   // Optix is not supported
   if (_renderEngine.compare("optix") == 0)
@@ -88,7 +87,7 @@ void DepthCameraTest::DepthCameraBoxes(
   }
 
   // Setup ign-rendering with an empty scene
-  auto *engine = gz::rendering::engine(_renderEngine);
+  auto *engine = ignition::rendering::engine(_renderEngine);
   if (!engine)
   {
     igndbg << "Engine '" << _renderEngine
@@ -96,7 +95,7 @@ void DepthCameraTest::DepthCameraBoxes(
     return;
   }
 
-  gz::rendering::ScenePtr scene = engine->CreateScene("scene");
+  ignition::rendering::ScenePtr scene = engine->CreateScene("scene");
 
   // red background
   scene->SetBackgroundColor(1.0, 0.0, 0.0);
@@ -108,16 +107,16 @@ void DepthCameraTest::DepthCameraBoxes(
 
   // Create an scene with a box in it
   scene->SetAmbientLight(1.0, 1.0, 1.0);
-  gz::rendering::VisualPtr root = scene->RootVisual();
+  ignition::rendering::VisualPtr root = scene->RootVisual();
 
   // create blue material
-  gz::rendering::MaterialPtr blue = scene->CreateMaterial();
+  ignition::rendering::MaterialPtr blue = scene->CreateMaterial();
   blue->SetAmbient(0.0, 0.0, 1.0);
   blue->SetDiffuse(0.0, 0.0, 1.0);
   blue->SetSpecular(0.0, 0.0, 1.0);
 
   // create box visual
-  gz::rendering::VisualPtr box = scene->CreateVisual();
+  ignition::rendering::VisualPtr box = scene->CreateVisual();
   box->AddGeometry(scene->CreateBox());
   box->SetOrigin(0.0, 0.0, 0.0);
   box->SetLocalPosition(boxPosition);
@@ -133,8 +132,8 @@ void DepthCameraTest::DepthCameraBoxes(
     auto depthCamera = scene->CreateDepthCamera("DepthCamera");
     ASSERT_NE(depthCamera, nullptr);
 
-    gz::math::Pose3d testPose(gz::math::Vector3d(0, 0, 0),
-        gz::math::Quaterniond::Identity);
+    ignition::math::Pose3d testPose(ignition::math::Vector3d(0, 0, 0),
+        ignition::math::Quaterniond::Identity);
     depthCamera->SetLocalPose(testPose);
 
     // Configure depth camera
@@ -158,7 +157,7 @@ void DepthCameraTest::DepthCameraBoxes(
 
     // Set a callback on the  camera sensor to get a depth camera frame
     float *scan = new float[imgHeight_ * imgWidth_];
-    gz::common::ConnectionPtr connection =
+    ignition::common::ConnectionPtr connection =
       depthCamera->ConnectNewDepthFrame(
           std::bind(&::OnNewDepthFrame, scan,
             std::placeholders::_1, std::placeholders::_2, std::placeholders::_3,
@@ -168,7 +167,7 @@ void DepthCameraTest::DepthCameraBoxes(
     unsigned int pointCloudChannelCount = 4u;
     float *pointCloudData = new float[
         imgHeight_ * imgWidth_ * pointCloudChannelCount];
-    gz::common::ConnectionPtr connection2 =
+    ignition::common::ConnectionPtr connection2 =
       depthCamera->ConnectNewRgbPointCloud(
           std::bind(&::OnNewRgbPointCloud, pointCloudData,
             std::placeholders::_1, std::placeholders::_2, std::placeholders::_3,
@@ -201,8 +200,8 @@ void DepthCameraTest::DepthCameraBoxes(
         * (depthCamera->ImageWidth() * pointCloudChannelCount)
         - pointCloudChannelCount;
 
-    float minVal = -gz::math::INF_D;
-    float maxVal = gz::math::INF_D;
+    float minVal = -ignition::math::INF_D;
+    float maxVal = ignition::math::INF_D;
 
     // Verify Depth
     // Depth sensor should see box in the middle of the image
@@ -261,7 +260,10 @@ void DepthCameraTest::DepthCameraBoxes(
       unsigned int ma = *mrgba >> 0 & 0xFF;
       EXPECT_EQ(0u, mr);
       EXPECT_EQ(0u, mg);
+#ifndef __APPLE__
+      // https://github.com/ignitionrobotics/ign-rendering/issues/332
       EXPECT_GT(mb, 0u);
+#endif
 
       // Far left and right points should be red (background color)
       float lc = pointCloudData[pcLeft + 3];
@@ -298,7 +300,7 @@ void DepthCameraTest::DepthCameraBoxes(
     }
 
     // Check that for a box really close it returns it is not seen
-    gz::math::Vector3d boxPositionNear(
+    ignition::math::Vector3d boxPositionNear(
         unitBoxSize * 0.5 + nearDist * 0.5, 0.0, 0.0);
     box->SetLocalPosition(boxPositionNear);
 
@@ -355,7 +357,7 @@ void DepthCameraTest::DepthCameraBoxes(
     }
 
     // Check that for a box really far it returns max val
-    gz::math::Vector3d boxPositionFar(
+    ignition::math::Vector3d boxPositionFar(
         unitBoxSize * 0.5 + farDist * 1.5, 0.0, 0.0);
     box->SetLocalPosition(boxPositionFar);
 
@@ -414,7 +416,7 @@ void DepthCameraTest::DepthCameraBoxes(
     }
 
     // Check that the depth values for a box do not warp.
-    gz::math::Vector3d boxPositionFillFrame(
+    ignition::math::Vector3d boxPositionFillFrame(
         unitBoxSize * 0.5 + 0.2, 0.0, 0.0);
     box->SetLocalPosition(boxPositionFillFrame);
 
@@ -463,8 +465,11 @@ void DepthCameraTest::DepthCameraBoxes(
           unsigned int a = *rgba >> 0 & 0xFF;
           EXPECT_EQ(0u, r);
           EXPECT_EQ(0u, g);
+#ifndef __APPLE__
+          // https://github.com/ignitionrobotics/ign-rendering/issues/332
           EXPECT_GT(b, 0u);
           EXPECT_EQ(255u, a);
+#endif
         }
       }
     }
@@ -477,9 +482,10 @@ void DepthCameraTest::DepthCameraBoxes(
   }
 
   engine->DestroyScene(scene);
-  gz::rendering::unloadEngine(engine->Name());
+  ignition::rendering::unloadEngine(engine->Name());
 }
 
+
 void DepthCameraTest::DepthCameraParticles(
     const std::string &_renderEngine)
 {
@@ -779,8 +785,7 @@ void DepthCameraTest::DepthCameraParticles(
   ignition::rendering::unloadEngine(engine->Name());
 }
 
-TEST_P(DepthCameraTest,
-  IGN_UTILS_TEST_DISABLED_ON_WIN32(DepthCameraBoxes))
+TEST_P(DepthCameraTest, DepthCameraBoxes)
 {
   DepthCameraBoxes(GetParam());
 }
@@ -791,7 +796,7 @@ TEST_P(DepthCameraTest, DepthCameraParticles)
 }
 
 INSTANTIATE_TEST_CASE_P(DepthCamera, DepthCameraTest,
-    RENDER_ENGINE_VALUES, gz::rendering::PrintToStringParam());
+    RENDER_ENGINE_VALUES, ignition::rendering::PrintToStringParam());
 
 //////////////////////////////////////////////////
 int main(int argc, char **argv)
