@@ -17,21 +17,21 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Image.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Image.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
 
-#include "gz/rendering/Camera.hh"
-#include "gz/rendering/DepthCamera.hh"
-#include "gz/rendering/DistortionPass.hh"
-#include "gz/rendering/GaussianNoisePass.hh"
-#include "gz/rendering/Image.hh"
-#include "gz/rendering/PixelFormat.hh"
-#include "gz/rendering/RenderEngine.hh"
-#include "gz/rendering/RenderingIface.hh"
-#include "gz/rendering/RenderPassSystem.hh"
-#include "gz/rendering/Scene.hh"
+#include "ignition/rendering/Camera.hh"
+#include "ignition/rendering/DepthCamera.hh"
+#include "ignition/rendering/DistortionPass.hh"
+#include "ignition/rendering/GaussianNoisePass.hh"
+#include "ignition/rendering/Image.hh"
+#include "ignition/rendering/PixelFormat.hh"
+#include "ignition/rendering/RenderEngine.hh"
+#include "ignition/rendering/RenderingIface.hh"
+#include "ignition/rendering/RenderPassSystem.hh"
+#include "ignition/rendering/Scene.hh"
 
 #define DOUBLE_TOL 1e-6
 unsigned int g_pointCloudCounter = 0;
@@ -46,7 +46,7 @@ void OnNewRgbPointCloud(float *_scanDest, const float *_scan,
   memcpy(_scanDest, _scan, size * sizeof(f));
   g_pointCloudCounter++;
 }
-using namespace gz;
+using namespace ignition;
 using namespace rendering;
 
 class RenderPassTest: public testing::Test,
@@ -175,7 +175,7 @@ void RenderPassTest::GaussianNoise(const std::string &_renderEngine)
 
   // Clean up
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -187,7 +187,7 @@ void RenderPassTest::DepthGaussianNoise(const std::string &_renderEngine)
   double aspectRatio_ = imgWidth/imgHeight;
 
   double unitBoxSize = 1.0;
-  math::Vector3d boxPosition(1.8, 0.0, 0.0);
+  ignition::math::Vector3d boxPosition(1.8, 0.0, 0.0);
 
   // Optix is not supported
   if (_renderEngine != "ogre2")
@@ -198,7 +198,7 @@ void RenderPassTest::DepthGaussianNoise(const std::string &_renderEngine)
   }
 
   // Setup ign-rendering with an empty scene
-  auto *engine = rendering::engine(_renderEngine);
+  auto *engine = ignition::rendering::engine(_renderEngine);
   if (!engine)
   {
     igndbg << "Engine '" << _renderEngine
@@ -206,23 +206,23 @@ void RenderPassTest::DepthGaussianNoise(const std::string &_renderEngine)
     return;
   }
 
-  ScenePtr scene = engine->CreateScene("scene");
+  ignition::rendering::ScenePtr scene = engine->CreateScene("scene");
 
   // red background
   scene->SetBackgroundColor(1.0, 0.0, 0.0);
 
   // Create an scene with a box in it
   scene->SetAmbientLight(1.0, 1.0, 1.0);
-  VisualPtr root = scene->RootVisual();
+  ignition::rendering::VisualPtr root = scene->RootVisual();
 
   // create blue material
-  MaterialPtr blue = scene->CreateMaterial();
+  ignition::rendering::MaterialPtr blue = scene->CreateMaterial();
   blue->SetAmbient(0.0, 0.0, 1.0);
   blue->SetDiffuse(0.0, 0.0, 1.0);
   blue->SetSpecular(0.0, 0.0, 1.0);
 
   // create box visual
-  VisualPtr box = scene->CreateVisual();
+  ignition::rendering::VisualPtr box = scene->CreateVisual();
   box->AddGeometry(scene->CreateBox());
   box->SetOrigin(0.0, 0.0, 0.0);
   box->SetLocalPosition(boxPosition);
@@ -238,8 +238,8 @@ void RenderPassTest::DepthGaussianNoise(const std::string &_renderEngine)
     auto depthCamera = scene->CreateDepthCamera("DepthCamera");
     ASSERT_NE(depthCamera, nullptr);
 
-    math::Pose3d testPose(math::Vector3d(0, 0, 0),
-        math::Quaterniond::Identity);
+    ignition::math::Pose3d testPose(ignition::math::Vector3d(0, 0, 0),
+        ignition::math::Quaterniond::Identity);
     depthCamera->SetLocalPose(testPose);
 
     // Configure depth camera
@@ -286,7 +286,7 @@ void RenderPassTest::DepthGaussianNoise(const std::string &_renderEngine)
     unsigned int pointCloudChannelCount = 4u;
     float *pointCloudData = new float[
         imgHeight * imgWidth * pointCloudChannelCount];
-    common::ConnectionPtr connection =
+    ignition::common::ConnectionPtr connection =
       depthCamera->ConnectNewRgbPointCloud(
           std::bind(&::OnNewRgbPointCloud, pointCloudData,
             std::placeholders::_1, std::placeholders::_2, std::placeholders::_3,
@@ -312,7 +312,7 @@ void RenderPassTest::DepthGaussianNoise(const std::string &_renderEngine)
         * (depthCamera->ImageWidth() * pointCloudChannelCount)
         - pointCloudChannelCount;
 
-    float maxVal = math::INF_D;
+    float maxVal = ignition::math::INF_D;
 
     // values should be well within 4-sigma
     float noiseTol = 4.0*noiseStdDev;
@@ -400,7 +400,7 @@ void RenderPassTest::DepthGaussianNoise(const std::string &_renderEngine)
   }
 
   engine->DestroyScene(scene);
-  unloadEngine(engine->Name());
+  ignition::rendering::unloadEngine(engine->Name());
 }
 
 void RenderPassTest::Distortion(const std::string &_renderEngine)
@@ -565,7 +565,7 @@ TEST_P(RenderPassTest, Distortion)
 
 INSTANTIATE_TEST_CASE_P(RenderPass, RenderPassTest,
     RENDER_ENGINE_VALUES,
-    PrintToStringParam());
+    ignition::rendering::PrintToStringParam());
 
 int main(int argc, char **argv)
 {
