@@ -17,21 +17,21 @@
 
 #include <gtest/gtest.h>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Filesystem.hh>
-#include <gz/common/Event.hh>
-#include <gz/utils/ExtraTestMacros.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/common/Event.hh>
+#include <ignition/utils/ExtraTestMacros.hh>
 
-#include <gz/math/Color.hh>
+#include <ignition/math/Color.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
 
-#include "gz/rendering/ParticleEmitter.hh"
-#include "gz/rendering/PixelFormat.hh"
-#include "gz/rendering/RenderEngine.hh"
-#include "gz/rendering/RenderingIface.hh"
-#include "gz/rendering/Scene.hh"
-#include "gz/rendering/ThermalCamera.hh"
+#include "ignition/rendering/ParticleEmitter.hh"
+#include "ignition/rendering/PixelFormat.hh"
+#include "ignition/rendering/RenderEngine.hh"
+#include "ignition/rendering/RenderingIface.hh"
+#include "ignition/rendering/Scene.hh"
+#include "ignition/rendering/ThermalCamera.hh"
 
 #define DEPTH_TOL 1e-4
 #define DOUBLE_TOL 1e-6
@@ -78,7 +78,7 @@ class ThermalCameraTest: public testing::Test,
   // Documentation inherited
   protected: void SetUp() override
   {
-    gz::common::Console::SetVerbosity(4);
+    ignition::common::Console::SetVerbosity(4);
   }
 };
 
@@ -91,7 +91,7 @@ void ThermalCameraTest::ThermalCameraBoxes(
   double aspectRatio = imgWidth/imgHeight;
 
   double unitBoxSize = 1.0;
-  gz::math::Vector3d boxPosition(1.8, 0.0, 0.0);
+  ignition::math::Vector3d boxPosition(1.8, 0.0, 0.0);
 
   // Optix is not supported
   if (_renderEngine.compare("optix") == 0)
@@ -109,7 +109,7 @@ void ThermalCameraTest::ThermalCameraBoxes(
   }
 
   // Setup ign-rendering with an empty scene
-  auto *engine = gz::rendering::engine(_renderEngine);
+  auto *engine = ignition::rendering::engine(_renderEngine);
   if (!engine)
   {
     igndbg << "Engine '" << _renderEngine
@@ -117,17 +117,17 @@ void ThermalCameraTest::ThermalCameraBoxes(
     return;
   }
 
-  gz::rendering::ScenePtr scene = engine->CreateScene("scene");
+  ignition::rendering::ScenePtr scene = engine->CreateScene("scene");
 
   // red background
   scene->SetBackgroundColor(1.0, 0.0, 0.0);
 
   // Create an scene with a box in it
   scene->SetAmbientLight(1.0, 1.0, 1.0);
-  gz::rendering::VisualPtr root = scene->RootVisual();
+  ignition::rendering::VisualPtr root = scene->RootVisual();
 
   // create box visual
-  gz::rendering::VisualPtr box = scene->CreateVisual();
+  ignition::rendering::VisualPtr box = scene->CreateVisual();
   box->AddGeometry(scene->CreateBox());
   box->SetOrigin(0.0, 0.0, 0.0);
   box->SetLocalPosition(boxPosition);
@@ -160,8 +160,8 @@ void ThermalCameraTest::ThermalCameraBoxes(
     auto thermalCamera = scene->CreateThermalCamera("ThermalCamera");
     ASSERT_NE(thermalCamera, nullptr);
 
-    gz::math::Pose3d testPose(gz::math::Vector3d(0, 0, 0),
-        gz::math::Quaterniond::Identity);
+    ignition::math::Pose3d testPose(ignition::math::Vector3d(0, 0, 0),
+        ignition::math::Quaterniond::Identity);
     thermalCamera->SetLocalPose(testPose);
 
     // Configure thermal camera
@@ -197,7 +197,7 @@ void ThermalCameraTest::ThermalCameraBoxes(
 
     // Set a callback on the  camera sensor to get a thermal camera frame
     uint16_t *thermalData = new uint16_t[imgHeight * imgWidth];
-    gz::common::ConnectionPtr connection =
+    ignition::common::ConnectionPtr connection =
       thermalCamera->ConnectNewThermalFrame(
           std::bind(&::OnNewThermalFrame, thermalData,
             std::placeholders::_1, std::placeholders::_2, std::placeholders::_3,
@@ -226,7 +226,7 @@ void ThermalCameraTest::ThermalCameraBoxes(
 
     // move box in front of near clip plane and verify the thermal
     // image returns all box temperature values
-    gz::math::Vector3d boxPositionNear(
+    ignition::math::Vector3d boxPositionNear(
         unitBoxSize * 0.5 + nearDist * 0.5, 0.0, 0.0);
     box->SetLocalPosition(boxPositionNear);
     thermalCamera->Update();
@@ -246,7 +246,7 @@ void ThermalCameraTest::ThermalCameraBoxes(
 
     // move box beyond far clip plane and verify the thermal
     // image returns all ambient temperature values
-    gz::math::Vector3d boxPositionFar(
+    ignition::math::Vector3d boxPositionFar(
         unitBoxSize * 0.5 + farDist * 1.5, 0.0, 0.0);
     box->SetLocalPosition(boxPositionFar);
     thermalCamera->Update();
@@ -267,7 +267,7 @@ void ThermalCameraTest::ThermalCameraBoxes(
   }
 
   engine->DestroyScene(scene);
-  gz::rendering::unloadEngine(engine->Name());
+  ignition::rendering::unloadEngine(engine->Name());
 }
 
 //////////////////////////////////////////////////
@@ -631,19 +631,17 @@ void ThermalCameraTest::ThermalCameraParticles(
 
 // See: https://github.com/gazebosim/gz-rendering/issues/654
 TEST_P(ThermalCameraTest,
-       IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(ThermalCameraBoxesUniformTemp))
+       IGN_UTILS_TEST_DISABLED_ON_MAC(ThermalCameraBoxesUniformTemp))
 {
   ThermalCameraBoxes(GetParam(), false);
 }
 
-TEST_P(ThermalCameraTest,
-       IGN_UTILS_TEST_DISABLED_ON_WIN32(ThermalCameraBoxesHeatSignature))
+TEST_P(ThermalCameraTest, ThermalCameraBoxesHeatSignature)
 {
   ThermalCameraBoxes(GetParam(), true);
 }
 
-TEST_P(ThermalCameraTest,
-       IGN_UTILS_TEST_DISABLED_ON_WIN32(ThermalCameraBoxesUniformTemp8Bit))
+TEST_P(ThermalCameraTest, ThermalCameraBoxesUniformTemp8Bit)
 {
   ThermalCameraBoxes8Bit(GetParam());
 }
@@ -654,7 +652,7 @@ TEST_P(ThermalCameraTest, ThermalCameraParticles)
 }
 
 INSTANTIATE_TEST_CASE_P(ThermalCamera, ThermalCameraTest,
-    RENDER_ENGINE_VALUES, gz::rendering::PrintToStringParam());
+    RENDER_ENGINE_VALUES, ignition::rendering::PrintToStringParam());
 
 //////////////////////////////////////////////////
 int main(int argc, char **argv)
